# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: protos/model/v1/config.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'protos/model/v1/config.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from formant.protos.model.v1 import commands_pb2 as protos_dot_model_dot_v1_dot_commands__pb2
from formant.protos.model.v1 import views_pb2 as protos_dot_model_dot_v1_dot_views__pb2
from formant.protos.model.v1 import ros_pb2 as protos_dot_model_dot_v1_dot_ros__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1cprotos/model/v1/config.proto\x12\x08v1.model\x1a\x1eprotos/model/v1/commands.proto\x1a\x1bprotos/model/v1/views.proto\x1a\x19protos/model/v1/ros.proto\x1a\x1egoogle/protobuf/wrappers.proto\"\xeb\x01\n\x17\x41gentConfigurationStore\x12\x15\n\ragent_version\x18\x01 \x01(\t\x12\x33\n\rconfiguration\x18\x02 \x01(\x0b\x32\x1c.v1.model.AgentConfiguration\x12.\n\x0b\x66\x65\x61ture_set\x18\x03 \x01(\x0b\x32\x19.v1.model.AgentFeatureSet\x12,\n\x08\x63ommands\x18\x04 \x01(\x0b\x32\x1a.v1.model.CommandsMetadata\x12&\n\x05views\x18\x05 \x01(\x0b\x32\x17.v1.model.ViewsMetadata\"\x8d\x02\n\x0f\x41gentFeatureSet\x12\x11\n\ttelemetry\x18\x01 \x01(\x08\x12\x1a\n\x12internal_telemetry\x18\x02 \x01(\x08\x12\x0e\n\x06teleop\x18\x03 \x01(\x08\x12\x15\n\rcustom_events\x18\x04 \x01(\x08\x12\x18\n\x10triggered_events\x18\x05 \x01(\x08\x12\x0b\n\x03ssh\x18\x06 \x01(\x08\x12\x17\n\x0fport_forwarding\x18\x07 \x01(\x08\x12\x10\n\x08\x63ommands\x18\x08 \x01(\x08\x12\x15\n\rinterventions\x18\t \x01(\x08\x12\x11\n\ton_demand\x18\n \x01(\x08\x12\x12\n\napp_config\x18\x0b \x01(\x08\x12\x14\n\x0c\x62lob_storage\x18\x0c \x01(\x08\"f\n\x12\x41gentConfiguration\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x36\n\x08\x64ocument\x18\x03 \x01(\x0b\x32$.v1.model.AgentConfigurationDocument\"\xbc\x05\n\x1a\x41gentConfigurationDocument\x12\x0f\n\x07version\x18\x01 \x01(\x03\x12<\n\x04tags\x18\x02 \x03(\x0b\x32..v1.model.AgentConfigurationDocument.TagsEntry\x12\x33\n\ttelemetry\x18\x03 \x01(\x0b\x32 .v1.model.TelemetryConfiguration\x12\x33\n\tresources\x18\x04 \x01(\x0b\x32 .v1.model.ResourcesConfiguration\x12\x37\n\x0b\x61pplication\x18\x05 \x01(\x0b\x32\".v1.model.ApplicationConfiguration\x12-\n\x06teleop\x18\x06 \x01(\x0b\x32\x1d.v1.model.TeleopConfiguration\x12>\n\x0fport_forwarding\x18\x07 \x01(\x0b\x32%.v1.model.PortForwardingConfiguration\x12%\n\tblob_data\x18\x08 \x01(\x0b\x32\x12.v1.model.BlobData\x12*\n\x0b\x64iagnostics\x18\t \x01(\x0b\x32\x15.v1.model.Diagnostics\x12\x33\n\x0fterminal_access\x18\n \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x30\n\x08\x61\x64\x61pters\x18\x0b \x03(\x0b\x32\x1e.v1.model.AdapterConfiguration\x12#\n\x08rtc_info\x18\x0c \x01(\x0b\x32\x11.v1.model.RtcInfo\x12\x31\n\x08realtime\x18\r \x01(\x0b\x32\x1f.v1.model.RealtimeConfiguration\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"n\n\x14\x41\x64\x61pterConfiguration\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0f\n\x07\x66ile_id\x18\x03 \x01(\t\x12\x14\n\x0c\x65xec_command\x18\x04 \x01(\t\x12\x15\n\rconfiguration\x18\x05 \x01(\t\"\xdc\x01\n\x13TeleopConfiguration\x12;\n\x0bros_streams\x18\x01 \x03(\x0b\x32&.v1.model.TeleopRosStreamConfiguration\x12\x41\n\x0e\x63ustom_streams\x18\x02 \x03(\x0b\x32).v1.model.TeleopCustomStreamConfiguration\x12\x45\n\x10hardware_streams\x18\x03 \x03(\x0b\x32+.v1.model.TeleopHardwareStreamConfiguration\"\xde\x01\n\x15RealtimeConfiguration\x12;\n\x0bros_streams\x18\x01 \x03(\x0b\x32&.v1.model.TeleopRosStreamConfiguration\x12\x41\n\x0e\x63ustom_streams\x18\x02 \x03(\x0b\x32).v1.model.TeleopCustomStreamConfiguration\x12\x45\n\x10hardware_streams\x18\x03 \x03(\x0b\x32+.v1.model.TeleopHardwareStreamConfiguration\"J\n\x1bPortForwardingConfiguration\x12+\n\x07\x65nabled\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\"\xdf\x02\n\x1cTeleopRosStreamConfiguration\x12\x12\n\ntopic_name\x18\x01 \x01(\t\x12*\n\ntopic_type\x18\x02 \x01(\x0e\x32\x16.v1.model.ROSTopicType\x12\"\n\x04mode\x18\x03 \x01(\x0e\x32\x14.v1.model.TeleopMode\x12\x14\n\x0c\x65ncode_video\x18\x04 \x01(\x08\x12\x13\n\x0b\x61udio_codec\x18\x05 \x01(\t\x12\x0f\n\x07quality\x18\x06 \x01(\t\x12\x1c\n\x14\x62\x61se_reference_frame\x18\x07 \x01(\t\x12\x13\n\x0blocal_frame\x18\x08 \x01(\t\x12\x15\n\roverlay_clock\x18\t \x01(\x08\x12\x0f\n\x07\x62itrate\x18\n \x01(\x03\x12 \n\x18\x64isable_adaptive_quality\x18\x0b \x01(\x08\x12\r\n\x05label\x18\x0c \x01(\t\x12\x13\n\x0bros_version\x18\r \x01(\t\"\xe8\x02\n!TeleopHardwareStreamConfiguration\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x17\n\x0frtc_stream_type\x18\x02 \x01(\t\x12\"\n\x04mode\x18\x03 \x01(\x0e\x32\x14.v1.model.TeleopMode\x12\x15\n\rhw_descriptor\x18\x04 \x01(\t\x12\x0f\n\x07quality\x18\x05 \x01(\t\x12\x15\n\rhardware_type\x18\x06 \x01(\t\x12\x1c\n\x14rtsp_encoding_needed\x18\x07 \x01(\x08\x12\x10\n\x08is_onvif\x18\x08 \x01(\x08\x12\x17\n\x0fip_cam_username\x18\t \x01(\t\x12\x17\n\x0fip_cam_password\x18\n \x01(\t\x12\x15\n\roverlay_clock\x18\x0b \x01(\x08\x12\x0f\n\x07\x62itrate\x18\x0c \x01(\x03\x12 \n\x18\x64isable_adaptive_quality\x18\r \x01(\x08\x12\r\n\x05label\x18\x0e \x01(\t\"\xec\x01\n\x1fTeleopCustomStreamConfiguration\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x17\n\x0frtc_stream_type\x18\x02 \x01(\t\x12\"\n\x04mode\x18\x03 \x01(\x0e\x32\x14.v1.model.TeleopMode\x12\x14\n\x0c\x65ncode_video\x18\x04 \x01(\x08\x12\x0f\n\x07quality\x18\x05 \x01(\t\x12\x15\n\roverlay_clock\x18\x06 \x01(\x08\x12\x0f\n\x07\x62itrate\x18\x07 \x01(\x03\x12 \n\x18\x64isable_adaptive_quality\x18\x08 \x01(\x08\x12\r\n\x05label\x18\t \x01(\t\"q\n\x16TelemetryConfiguration\x12.\n\x07streams\x18\x01 \x03(\x0b\x32\x1d.v1.model.StreamConfiguration\x12\'\n\x03ros\x18\x02 \x01(\x0b\x32\x1a.v1.model.ROSConfiguration\"\xa8\x01\n\x18\x41pplicationConfiguration\x12S\n\x11\x63onfiguration_map\x18\x01 \x03(\x0b\x32\x38.v1.model.ApplicationConfiguration.ConfigurationMapEntry\x1a\x37\n\x15\x43onfigurationMapEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x97\x02\n\x16ResourcesConfiguration\x12)\n\x04\x64isk\x18\x01 \x01(\x0b\x32\x1b.v1.model.DiskConfiguration\x12\x38\n\x12stream_throttle_hz\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12\x1b\n\x13low_bandwidth_agent\x18\x03 \x01(\x08\x12\x1c\n\x14\x64\x61tapoint_batch_size\x18\x04 \x01(\x04\x12\"\n\x1a\x64\x61tapoint_batchLifetime_ms\x18\x05 \x01(\x04\x12\x18\n\x10\x61sset_batch_size\x18\x06 \x01(\x04\x12\x1f\n\x17\x61sset_batch_lifetime_ms\x18\x07 \x01(\x04\"G\n\x11\x44iskConfiguration\x12\x13\n\x0b\x62uffer_size\x18\x01 \x01(\x03\x12\x1d\n\x15on_demand_buffer_size\x18\x02 \x01(\x03\"4\n\x10ROSConfiguration\x12 \n\x18world_reference_frame_id\x18\x01 \x01(\t\"\xb8\x05\n\x13StreamConfiguration\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x35\n\x04tags\x18\x02 \x03(\x0b\x32\'.v1.model.StreamConfiguration.TagsEntry\x12\'\n\tros_topic\x18\x03 \x01(\x0b\x32\x12.v1.model.ROSTopicH\x00\x12\x35\n\x10ros_localization\x18\x04 \x01(\x0b\x32\x19.v1.model.ROSLocalizationH\x00\x12\x33\n\x0f\x64irectory_watch\x18\x05 \x01(\x0b\x32\x18.v1.model.DirectoryWatchH\x00\x12\'\n\tfile_tail\x18\x06 \x01(\x0b\x32\x12.v1.model.FileTailH\x00\x12\x38\n\x12ros_transform_tree\x18\x07 \x01(\x0b\x32\x1a.v1.model.ROSTransformTreeH\x00\x12\"\n\x06\x63ustom\x18\t \x01(\x0b\x32\x10.v1.model.CustomH\x00\x12&\n\x08hardware\x18\n \x01(\x0b\x32\x12.v1.model.HardwareH\x00\x12\x31\n\x0bthrottle_hz\x18\x08 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12,\n\x08\x64isabled\x18\x13 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12-\n\ton_demand\x18\x14 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x39\n\ttransform\x18\x15 \x01(\x0b\x32&.v1.model.StreamTransformConfiguration\x12\x0f\n\x07quality\x18\x16 \x01(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x0f\n\rconfiguration\"Z\n\x1cStreamTransformConfiguration\x12:\n\x16video_encoding_enabled\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\"\x18\n\x08\x42lobData\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\t\"r\n\x0b\x44iagnostics\x12/\n\x0breport_logs\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x32\n\x0ereport_metrics\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\"\x08\n\x06\x43ustom\"\x81\x02\n\x08Hardware\x12\x15\n\rhw_descriptor\x18\x01 \x01(\t\x12\x1b\n\x13\x61udio_hw_descriptor\x18\x03 \x01(\t\x12\x15\n\rhardware_type\x18\x04 \x01(\t\x12\x1c\n\x14rtsp_encoding_needed\x18\x05 \x01(\x08\x12\x10\n\x08is_onvif\x18\x06 \x01(\x08\x12\x17\n\x0fip_cam_username\x18\x07 \x01(\t\x12\x17\n\x0fip_cam_password\x18\x08 \x01(\t\x12\x15\n\roverlay_clock\x18\t \x01(\x08\x12\x0f\n\x07\x62itrate\x18\n \x01(\x03\x12 \n\x18\x64isable_adaptive_quality\x18\x0b \x01(\x08\"s\n\x0e\x44irectoryWatch\x12\x11\n\tdirectory\x18\x01 \x01(\t\x12\x11\n\textension\x18\x02 \x01(\t\x12%\n\tfile_type\x18\x03 \x01(\x0e\x32\x12.v1.model.FileType\x12\x14\n\x0cremote_agent\x18\x04 \x01(\x08\"}\n\x08\x46ileTail\x12\x10\n\x08\x66ilename\x18\x01 \x01(\t\x12)\n\x0b\x66ile_format\x18\x02 \x01(\x0e\x32\x14.v1.model.FileFormat\x12\x10\n\x08time_key\x18\x03 \x01(\t\x12\x13\n\x0btime_format\x18\x04 \x01(\t\x12\r\n\x05regex\x18\x05 \x01(\t\"g\n\x07RtcInfo\x12\"\n\x1artc_ice_transport_policies\x18\x01 \x03(\t\x12\x1f\n\x17rtc_ice_server_protocol\x18\x02 \x01(\t\x12\x17\n\x0fuse_all_servers\x18\x03 \x01(\x08*&\n\nTeleopMode\x12\x0b\n\x07\x43OMMAND\x10\x00\x12\x0b\n\x07OBSERVE\x10\x01*&\n\nFileFormat\x12\x0e\n\nPLAIN_TEXT\x10\x00\x12\x08\n\x04JSON\x10\x01*;\n\x08\x46ileType\x12\x08\n\x04\x46ILE\x10\x00\x12\t\n\x05IMAGE\x10\x01\x12\x0f\n\x0bPOINT_CLOUD\x10\x04\x12\t\n\x05VIDEO\x10\x05\x42+Z)github.com/FormantIO/genproto/go/v1/modelb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'protos.model.v1.config_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z)github.com/FormantIO/genproto/go/v1/model'
  _globals['_AGENTCONFIGURATIONDOCUMENT_TAGSENTRY']._loaded_options = None
  _globals['_AGENTCONFIGURATIONDOCUMENT_TAGSENTRY']._serialized_options = b'8\001'
  _globals['_APPLICATIONCONFIGURATION_CONFIGURATIONMAPENTRY']._loaded_options = None
  _globals['_APPLICATIONCONFIGURATION_CONFIGURATIONMAPENTRY']._serialized_options = b'8\001'
  _globals['_STREAMCONFIGURATION_TAGSENTRY']._loaded_options = None
  _globals['_STREAMCONFIGURATION_TAGSENTRY']._serialized_options = b'8\001'
  _globals['_TELEOPMODE']._serialized_start=5318
  _globals['_TELEOPMODE']._serialized_end=5356
  _globals['_FILEFORMAT']._serialized_start=5358
  _globals['_FILEFORMAT']._serialized_end=5396
  _globals['_FILETYPE']._serialized_start=5398
  _globals['_FILETYPE']._serialized_end=5457
  _globals['_AGENTCONFIGURATIONSTORE']._serialized_start=163
  _globals['_AGENTCONFIGURATIONSTORE']._serialized_end=398
  _globals['_AGENTFEATURESET']._serialized_start=401
  _globals['_AGENTFEATURESET']._serialized_end=670
  _globals['_AGENTCONFIGURATION']._serialized_start=672
  _globals['_AGENTCONFIGURATION']._serialized_end=774
  _globals['_AGENTCONFIGURATIONDOCUMENT']._serialized_start=777
  _globals['_AGENTCONFIGURATIONDOCUMENT']._serialized_end=1477
  _globals['_AGENTCONFIGURATIONDOCUMENT_TAGSENTRY']._serialized_start=1434
  _globals['_AGENTCONFIGURATIONDOCUMENT_TAGSENTRY']._serialized_end=1477
  _globals['_ADAPTERCONFIGURATION']._serialized_start=1479
  _globals['_ADAPTERCONFIGURATION']._serialized_end=1589
  _globals['_TELEOPCONFIGURATION']._serialized_start=1592
  _globals['_TELEOPCONFIGURATION']._serialized_end=1812
  _globals['_REALTIMECONFIGURATION']._serialized_start=1815
  _globals['_REALTIMECONFIGURATION']._serialized_end=2037
  _globals['_PORTFORWARDINGCONFIGURATION']._serialized_start=2039
  _globals['_PORTFORWARDINGCONFIGURATION']._serialized_end=2113
  _globals['_TELEOPROSSTREAMCONFIGURATION']._serialized_start=2116
  _globals['_TELEOPROSSTREAMCONFIGURATION']._serialized_end=2467
  _globals['_TELEOPHARDWARESTREAMCONFIGURATION']._serialized_start=2470
  _globals['_TELEOPHARDWARESTREAMCONFIGURATION']._serialized_end=2830
  _globals['_TELEOPCUSTOMSTREAMCONFIGURATION']._serialized_start=2833
  _globals['_TELEOPCUSTOMSTREAMCONFIGURATION']._serialized_end=3069
  _globals['_TELEMETRYCONFIGURATION']._serialized_start=3071
  _globals['_TELEMETRYCONFIGURATION']._serialized_end=3184
  _globals['_APPLICATIONCONFIGURATION']._serialized_start=3187
  _globals['_APPLICATIONCONFIGURATION']._serialized_end=3355
  _globals['_APPLICATIONCONFIGURATION_CONFIGURATIONMAPENTRY']._serialized_start=3300
  _globals['_APPLICATIONCONFIGURATION_CONFIGURATIONMAPENTRY']._serialized_end=3355
  _globals['_RESOURCESCONFIGURATION']._serialized_start=3358
  _globals['_RESOURCESCONFIGURATION']._serialized_end=3637
  _globals['_DISKCONFIGURATION']._serialized_start=3639
  _globals['_DISKCONFIGURATION']._serialized_end=3710
  _globals['_ROSCONFIGURATION']._serialized_start=3712
  _globals['_ROSCONFIGURATION']._serialized_end=3764
  _globals['_STREAMCONFIGURATION']._serialized_start=3767
  _globals['_STREAMCONFIGURATION']._serialized_end=4463
  _globals['_STREAMCONFIGURATION_TAGSENTRY']._serialized_start=1434
  _globals['_STREAMCONFIGURATION_TAGSENTRY']._serialized_end=1477
  _globals['_STREAMTRANSFORMCONFIGURATION']._serialized_start=4465
  _globals['_STREAMTRANSFORMCONFIGURATION']._serialized_end=4555
  _globals['_BLOBDATA']._serialized_start=4557
  _globals['_BLOBDATA']._serialized_end=4581
  _globals['_DIAGNOSTICS']._serialized_start=4583
  _globals['_DIAGNOSTICS']._serialized_end=4697
  _globals['_CUSTOM']._serialized_start=4699
  _globals['_CUSTOM']._serialized_end=4707
  _globals['_HARDWARE']._serialized_start=4710
  _globals['_HARDWARE']._serialized_end=4967
  _globals['_DIRECTORYWATCH']._serialized_start=4969
  _globals['_DIRECTORYWATCH']._serialized_end=5084
  _globals['_FILETAIL']._serialized_start=5086
  _globals['_FILETAIL']._serialized_end=5211
  _globals['_RTCINFO']._serialized_start=5213
  _globals['_RTCINFO']._serialized_end=5316
# @@protoc_insertion_point(module_scope)



import datetime
from typing import Any, Dict, List, Optional, Type, TypeVar, Union

import attr
from dateutil.parser import isoparse

from ..models.email_configuration_email_type import EmailConfigurationEmailType
from ..models.email_configuration_language import EmailConfigurationLanguage
from ..types import UNSET, Unset

T = TypeVar("T", bound="EmailConfiguration")


@attr.s(auto_attribs=True)
class EmailConfiguration:
    """
    Attributes:
        email_type (EmailConfigurationEmailType):
        active (bool):
        organization_id (Union[Unset, str]): ID of the organization to which this user belongs.
        subject (Union[Unset, None, str]):
        email_content (Union[Unset, None, str]):
        email_address_alias (Union[Unset, None, str]):
        team_id (Optional[str]):
        language (Union[Unset, EmailConfigurationLanguage]):
        id (Union[Unset, str]):
        created_at (Union[Unset, datetime.datetime]):
        updated_at (Union[Unset, datetime.datetime]):
    """

    email_type: EmailConfigurationEmailType
    active: bool
    team_id: Optional[str]
    organization_id: Union[Unset, str] = UNSET
    subject: Union[Unset, None, str] = UNSET
    email_content: Union[Unset, None, str] = UNSET
    email_address_alias: Union[Unset, None, str] = UNSET
    language: Union[Unset, EmailConfigurationLanguage] = UNSET
    id: Union[Unset, str] = UNSET
    created_at: Union[Unset, datetime.datetime] = UNSET
    updated_at: Union[Unset, datetime.datetime] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        email_type = self.email_type.value

        active = self.active
        organization_id = self.organization_id
        subject = self.subject
        email_content = self.email_content
        email_address_alias = self.email_address_alias
        team_id = self.team_id
        language: Union[Unset, str] = UNSET
        if not isinstance(self.language, Unset):
            language = self.language.value

        id = self.id
        created_at: Union[Unset, str] = UNSET
        if not isinstance(self.created_at, Unset):
            created_at = self.created_at.isoformat()

        updated_at: Union[Unset, str] = UNSET
        if not isinstance(self.updated_at, Unset):
            updated_at = self.updated_at.isoformat()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "emailType": email_type,
                "active": active,
                "teamId": team_id,
            }
        )
        if organization_id is not UNSET:
            field_dict["organizationId"] = organization_id
        if subject is not UNSET:
            field_dict["subject"] = subject
        if email_content is not UNSET:
            field_dict["emailContent"] = email_content
        if email_address_alias is not UNSET:
            field_dict["emailAddressAlias"] = email_address_alias
        if language is not UNSET:
            field_dict["language"] = language
        if id is not UNSET:
            field_dict["id"] = id
        if created_at is not UNSET:
            field_dict["createdAt"] = created_at
        if updated_at is not UNSET:
            field_dict["updatedAt"] = updated_at

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        email_type = EmailConfigurationEmailType(d.pop("emailType"))

        active = d.pop("active")

        organization_id = d.pop("organizationId", UNSET)

        subject = d.pop("subject", UNSET)

        email_content = d.pop("emailContent", UNSET)

        email_address_alias = d.pop("emailAddressAlias", UNSET)

        team_id = d.pop("teamId")

        _language = d.pop("language", UNSET)
        language: Union[Unset, EmailConfigurationLanguage]
        if isinstance(_language, Unset):
            language = UNSET
        else:
            language = EmailConfigurationLanguage(_language)

        id = d.pop("id", UNSET)

        _created_at = d.pop("createdAt", UNSET)
        created_at: Union[Unset, datetime.datetime]
        if isinstance(_created_at, Unset):
            created_at = UNSET
        else:
            created_at = isoparse(_created_at)

        _updated_at = d.pop("updatedAt", UNSET)
        updated_at: Union[Unset, datetime.datetime]
        if isinstance(_updated_at, Unset):
            updated_at = UNSET
        else:
            updated_at = isoparse(_updated_at)

        email_configuration = cls(
            email_type=email_type,
            active=active,
            organization_id=organization_id,
            subject=subject,
            email_content=email_content,
            email_address_alias=email_address_alias,
            team_id=team_id,
            language=language,
            id=id,
            created_at=created_at,
            updated_at=updated_at,
        )

        email_configuration.additional_properties = d
        return email_configuration

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.label import Label
    from ..models.labeled_polygon import LabeledPolygon


T = TypeVar("T", bound="LabelingRequestData")


@attr.s(auto_attribs=True)
class LabelingRequestData:
    """
    Attributes:
        instruction (str): Prompt to be shown to the user to resolve the intervention request.
        image_url (str): URL of the image file to be shown during the intervention request.
        labels (List['Label']):
        hint (Union[Unset, List['LabeledPolygon']]): (x,y) coordinates creating a box around the area in the image you
            would like to suggest as the most likely location of the object in question.
        title (Union[Unset, str]): Title of the intervention request window.
    """

    instruction: str
    image_url: str
    labels: List["Label"]
    hint: Union[Unset, List["LabeledPolygon"]] = UNSET
    title: Union[Unset, str] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        instruction = self.instruction
        image_url = self.image_url
        labels = []
        for labels_item_data in self.labels:
            labels_item = labels_item_data.to_dict()

            labels.append(labels_item)

        hint: Union[Unset, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.hint, Unset):
            hint = []
            for hint_item_data in self.hint:
                hint_item = hint_item_data.to_dict()

                hint.append(hint_item)

        title = self.title

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "instruction": instruction,
                "imageUrl": image_url,
                "labels": labels,
            }
        )
        if hint is not UNSET:
            field_dict["hint"] = hint
        if title is not UNSET:
            field_dict["title"] = title

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.label import Label
        from ..models.labeled_polygon import LabeledPolygon

        d = src_dict.copy()
        instruction = d.pop("instruction")

        image_url = d.pop("imageUrl")

        labels = []
        _labels = d.pop("labels")
        for labels_item_data in _labels:
            labels_item = Label.from_dict(labels_item_data)

            labels.append(labels_item)

        hint = []
        _hint = d.pop("hint", UNSET)
        for hint_item_data in _hint or []:
            hint_item = LabeledPolygon.from_dict(hint_item_data)

            hint.append(hint_item)

        title = d.pop("title", UNSET)

        labeling_request_data = cls(
            instruction=instruction,
            image_url=image_url,
            labels=labels,
            hint=hint,
            title=title,
        )

        labeling_request_data.additional_properties = d
        return labeling_request_data

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from formant.sdk.cloud.v2.formant_query_api_client.models import Goal, StreamDataType, VideoMimeType, Health, StreamAggregateDataType, Twist, ImageAnnotation, StreamDataPointsItem, StreamDataTags, Bitset, Video, NumericSetEntry, Query, StreamAggregateDataTags, StreamDataListResponse, BoundingBox, Quaternion, HealthStatus, File, StreamData, Transform, Location, QueryAggregate, Map, Vector3, Battery, Video,VideoMimeType, Image, Odometry, QueryTypesItem, Localization, Health,HealthStatus, PointCloud, StreamAggregateData, Path, TransformNode
from formant.sdk.cloud.v2.formant_query_api_client.api.query import query_controller_query
from formant.sdk.cloud.v2.formant_query_api_client.types import *


from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..models.device_teleop_hardware_stream_configuration_hardware_type import (
    DeviceTeleopHardwareStreamConfigurationHardwareType,
)
from ..models.device_teleop_hardware_stream_configuration_mode import DeviceTeleopHardwareStreamConfigurationMode
from ..models.device_teleop_hardware_stream_configuration_quality import DeviceTeleopHardwareStreamConfigurationQuality
from ..models.device_teleop_hardware_stream_configuration_rtc_stream_type import (
    DeviceTeleopHardwareStreamConfigurationRtcStreamType,
)
from ..types import UNSET, Unset

T = TypeVar("T", bound="DeviceTeleopHardwareStreamConfiguration")


@attr.s(auto_attribs=True)
class DeviceTeleopHardwareStreamConfiguration:
    """
    Attributes:
        name (str):
        rtc_stream_type (DeviceTeleopHardwareStreamConfigurationRtcStreamType):
        mode (DeviceTeleopHardwareStreamConfigurationMode):
        hw_descriptor (str):
        hardware_type (DeviceTeleopHardwareStreamConfigurationHardwareType):
        quality (DeviceTeleopHardwareStreamConfigurationQuality):
        label (Union[Unset, str]):
        rtsp_encoding_needed (Union[Unset, bool]):
        is_onvif (Union[Unset, bool]):
        ip_cam_username (Union[Unset, str]):
        ip_cam_password (Union[Unset, str]):
        overlay_clock (Union[Unset, bool]):
        bitrate (Union[Unset, int]):
        disable_adaptive_quality (Union[Unset, bool]):
    """

    name: str
    rtc_stream_type: DeviceTeleopHardwareStreamConfigurationRtcStreamType
    mode: DeviceTeleopHardwareStreamConfigurationMode
    hw_descriptor: str
    hardware_type: DeviceTeleopHardwareStreamConfigurationHardwareType
    quality: DeviceTeleopHardwareStreamConfigurationQuality
    label: Union[Unset, str] = UNSET
    rtsp_encoding_needed: Union[Unset, bool] = UNSET
    is_onvif: Union[Unset, bool] = UNSET
    ip_cam_username: Union[Unset, str] = UNSET
    ip_cam_password: Union[Unset, str] = UNSET
    overlay_clock: Union[Unset, bool] = UNSET
    bitrate: Union[Unset, int] = UNSET
    disable_adaptive_quality: Union[Unset, bool] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        name = self.name
        rtc_stream_type = self.rtc_stream_type.value

        mode = self.mode.value

        hw_descriptor = self.hw_descriptor
        hardware_type = self.hardware_type.value

        quality = self.quality.value

        label = self.label
        rtsp_encoding_needed = self.rtsp_encoding_needed
        is_onvif = self.is_onvif
        ip_cam_username = self.ip_cam_username
        ip_cam_password = self.ip_cam_password
        overlay_clock = self.overlay_clock
        bitrate = self.bitrate
        disable_adaptive_quality = self.disable_adaptive_quality

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "name": name,
                "rtcStreamType": rtc_stream_type,
                "mode": mode,
                "hwDescriptor": hw_descriptor,
                "hardwareType": hardware_type,
                "quality": quality,
            }
        )
        if label is not UNSET:
            field_dict["label"] = label
        if rtsp_encoding_needed is not UNSET:
            field_dict["rtspEncodingNeeded"] = rtsp_encoding_needed
        if is_onvif is not UNSET:
            field_dict["isOnvif"] = is_onvif
        if ip_cam_username is not UNSET:
            field_dict["ipCamUsername"] = ip_cam_username
        if ip_cam_password is not UNSET:
            field_dict["ipCamPassword"] = ip_cam_password
        if overlay_clock is not UNSET:
            field_dict["overlayClock"] = overlay_clock
        if bitrate is not UNSET:
            field_dict["bitrate"] = bitrate
        if disable_adaptive_quality is not UNSET:
            field_dict["disableAdaptiveQuality"] = disable_adaptive_quality

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        name = d.pop("name")

        rtc_stream_type = DeviceTeleopHardwareStreamConfigurationRtcStreamType(d.pop("rtcStreamType"))

        mode = DeviceTeleopHardwareStreamConfigurationMode(d.pop("mode"))

        hw_descriptor = d.pop("hwDescriptor")

        hardware_type = DeviceTeleopHardwareStreamConfigurationHardwareType(d.pop("hardwareType"))

        quality = DeviceTeleopHardwareStreamConfigurationQuality(d.pop("quality"))

        label = d.pop("label", UNSET)

        rtsp_encoding_needed = d.pop("rtspEncodingNeeded", UNSET)

        is_onvif = d.pop("isOnvif", UNSET)

        ip_cam_username = d.pop("ipCamUsername", UNSET)

        ip_cam_password = d.pop("ipCamPassword", UNSET)

        overlay_clock = d.pop("overlayClock", UNSET)

        bitrate = d.pop("bitrate", UNSET)

        disable_adaptive_quality = d.pop("disableAdaptiveQuality", UNSET)

        device_teleop_hardware_stream_configuration = cls(
            name=name,
            rtc_stream_type=rtc_stream_type,
            mode=mode,
            hw_descriptor=hw_descriptor,
            hardware_type=hardware_type,
            quality=quality,
            label=label,
            rtsp_encoding_needed=rtsp_encoding_needed,
            is_onvif=is_onvif,
            ip_cam_username=ip_cam_username,
            ip_cam_password=ip_cam_password,
            overlay_clock=overlay_clock,
            bitrate=bitrate,
            disable_adaptive_quality=disable_adaptive_quality,
        )

        device_teleop_hardware_stream_configuration.additional_properties = d
        return device_teleop_hardware_stream_configuration

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, List, Type, TypeVar, Union, cast

import attr

from ..models.device_stream_ros_localization_configuration_ros_version import (
    DeviceStreamRosLocalizationConfigurationRosVersion,
)
from ..models.device_stream_ros_localization_configuration_type import DeviceStreamRosLocalizationConfigurationType
from ..types import UNSET, Unset

T = TypeVar("T", bound="DeviceStreamRosLocalizationConfiguration")


@attr.s(auto_attribs=True)
class DeviceStreamRosLocalizationConfiguration:
    """
    Attributes:
        type (DeviceStreamRosLocalizationConfigurationType):
        base_reference_frame (str):
        odom_topic (str):
        ros_version (DeviceStreamRosLocalizationConfigurationRosVersion):
        map_topic (Union[Unset, str]):
        point_cloud_topics (Union[Unset, List[str]]):
        path_topic (Union[Unset, str]):
        goal_topic (Union[Unset, str]):
    """

    type: DeviceStreamRosLocalizationConfigurationType
    base_reference_frame: str
    odom_topic: str
    ros_version: DeviceStreamRosLocalizationConfigurationRosVersion
    map_topic: Union[Unset, str] = UNSET
    point_cloud_topics: Union[Unset, List[str]] = UNSET
    path_topic: Union[Unset, str] = UNSET
    goal_topic: Union[Unset, str] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        type = self.type.value

        base_reference_frame = self.base_reference_frame
        odom_topic = self.odom_topic
        ros_version = self.ros_version.value

        map_topic = self.map_topic
        point_cloud_topics: Union[Unset, List[str]] = UNSET
        if not isinstance(self.point_cloud_topics, Unset):
            point_cloud_topics = self.point_cloud_topics

        path_topic = self.path_topic
        goal_topic = self.goal_topic

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "type": type,
                "baseReferenceFrame": base_reference_frame,
                "odomTopic": odom_topic,
                "rosVersion": ros_version,
            }
        )
        if map_topic is not UNSET:
            field_dict["mapTopic"] = map_topic
        if point_cloud_topics is not UNSET:
            field_dict["pointCloudTopics"] = point_cloud_topics
        if path_topic is not UNSET:
            field_dict["pathTopic"] = path_topic
        if goal_topic is not UNSET:
            field_dict["goalTopic"] = goal_topic

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        type = DeviceStreamRosLocalizationConfigurationType(d.pop("type"))

        base_reference_frame = d.pop("baseReferenceFrame")

        odom_topic = d.pop("odomTopic")

        ros_version = DeviceStreamRosLocalizationConfigurationRosVersion(d.pop("rosVersion"))

        map_topic = d.pop("mapTopic", UNSET)

        point_cloud_topics = cast(List[str], d.pop("pointCloudTopics", UNSET))

        path_topic = d.pop("pathTopic", UNSET)

        goal_topic = d.pop("goalTopic", UNSET)

        device_stream_ros_localization_configuration = cls(
            type=type,
            base_reference_frame=base_reference_frame,
            odom_topic=odom_topic,
            ros_version=ros_version,
            map_topic=map_topic,
            point_cloud_topics=point_cloud_topics,
            path_topic=path_topic,
            goal_topic=goal_topic,
        )

        device_stream_ros_localization_configuration.additional_properties = d
        return device_stream_ros_localization_configuration

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from formant.sdk.cloud.v2.src.resources.resources import Resources
from formant.sdk.cloud.v2.formant_query_api_client.api.presence import presence_controller_count
from formant.sdk.cloud.v2.formant_query_api_client.models.interval_query import IntervalQuery

class Presence(Resources):

    def count(self, interval_query: IntervalQuery):
        """Tells you if data has been ingested within a certain time period"""
        client = self._get_client()
        response = presence_controller_count.sync_detailed(client=client, json_body=interval_query)
        return response

    async def count_async(self, interval_query: IntervalQuery):
        """Tells you if data has been ingested within a certain time period"""
        client = self._get_client()
        response = await presence_controller_count.asyncio_detailed(client=client, json_body=interval_query)
        return response


from typing import Any, Dict, List, Type, TypeVar

import attr

T = TypeVar("T", bound="CheckSsoResult")


@attr.s(auto_attribs=True)
class CheckSsoResult:
    """
    Attributes:
        issuer (str):
        client_id (str):
        is_sso (bool):
    """

    issuer: str
    client_id: str
    is_sso: bool
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        issuer = self.issuer
        client_id = self.client_id
        is_sso = self.is_sso

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "issuer": issuer,
                "clientId": client_id,
                "isSso": is_sso,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        issuer = d.pop("issuer")

        client_id = d.pop("clientId")

        is_sso = d.pop("isSso")

        check_sso_result = cls(
            issuer=issuer,
            client_id=client_id,
            is_sso=is_sso,
        )

        check_sso_result.additional_properties = d
        return check_sso_result

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: protos/protoc_gen_swagger/options/openapiv2.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'protos/protoc_gen_swagger/options/openapiv2.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1protos/protoc_gen_swagger/options/openapiv2.proto\x12\'grpc.gateway.protoc_gen_swagger.options\x1a\x19google/protobuf/any.proto\x1a\x1cgoogle/protobuf/struct.proto\"\xa0\x07\n\x07Swagger\x12\x0f\n\x07swagger\x18\x01 \x01(\t\x12;\n\x04info\x18\x02 \x01(\x0b\x32-.grpc.gateway.protoc_gen_swagger.options.Info\x12\x0c\n\x04host\x18\x03 \x01(\t\x12\x11\n\tbase_path\x18\x04 \x01(\t\x12O\n\x07schemes\x18\x05 \x03(\x0e\x32>.grpc.gateway.protoc_gen_swagger.options.Swagger.SwaggerScheme\x12\x10\n\x08\x63onsumes\x18\x06 \x03(\t\x12\x10\n\x08produces\x18\x07 \x03(\t\x12R\n\tresponses\x18\n \x03(\x0b\x32?.grpc.gateway.protoc_gen_swagger.options.Swagger.ResponsesEntry\x12Z\n\x14security_definitions\x18\x0b \x01(\x0b\x32<.grpc.gateway.protoc_gen_swagger.options.SecurityDefinitions\x12N\n\x08security\x18\x0c \x03(\x0b\x32<.grpc.gateway.protoc_gen_swagger.options.SecurityRequirement\x12U\n\rexternal_docs\x18\x0e \x01(\x0b\x32>.grpc.gateway.protoc_gen_swagger.options.ExternalDocumentation\x12T\n\nextensions\x18\x0f \x03(\x0b\x32@.grpc.gateway.protoc_gen_swagger.options.Swagger.ExtensionsEntry\x1a\x63\n\x0eResponsesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12@\n\x05value\x18\x02 \x01(\x0b\x32\x31.grpc.gateway.protoc_gen_swagger.options.Response:\x02\x38\x01\x1aI\n\x0f\x45xtensionsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12%\n\x05value\x18\x02 \x01(\x0b\x32\x16.google.protobuf.Value:\x02\x38\x01\"B\n\rSwaggerScheme\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x08\n\x04HTTP\x10\x01\x12\t\n\x05HTTPS\x10\x02\x12\x06\n\x02WS\x10\x03\x12\x07\n\x03WSS\x10\x04J\x04\x08\x08\x10\tJ\x04\x08\t\x10\nJ\x04\x08\r\x10\x0e\"\xa9\x05\n\tOperation\x12\x0c\n\x04tags\x18\x01 \x03(\t\x12\x0f\n\x07summary\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12U\n\rexternal_docs\x18\x04 \x01(\x0b\x32>.grpc.gateway.protoc_gen_swagger.options.ExternalDocumentation\x12\x14\n\x0coperation_id\x18\x05 \x01(\t\x12\x10\n\x08\x63onsumes\x18\x06 \x03(\t\x12\x10\n\x08produces\x18\x07 \x03(\t\x12T\n\tresponses\x18\t \x03(\x0b\x32\x41.grpc.gateway.protoc_gen_swagger.options.Operation.ResponsesEntry\x12\x0f\n\x07schemes\x18\n \x03(\t\x12\x12\n\ndeprecated\x18\x0b \x01(\x08\x12N\n\x08security\x18\x0c \x03(\x0b\x32<.grpc.gateway.protoc_gen_swagger.options.SecurityRequirement\x12V\n\nextensions\x18\r \x03(\x0b\x32\x42.grpc.gateway.protoc_gen_swagger.options.Operation.ExtensionsEntry\x1a\x63\n\x0eResponsesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12@\n\x05value\x18\x02 \x01(\x0b\x32\x31.grpc.gateway.protoc_gen_swagger.options.Response:\x02\x38\x01\x1aI\n\x0f\x45xtensionsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12%\n\x05value\x18\x02 \x01(\x0b\x32\x16.google.protobuf.Value:\x02\x38\x01J\x04\x08\x08\x10\t\"\x8e\x02\n\x08Response\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12?\n\x06schema\x18\x02 \x01(\x0b\x32/.grpc.gateway.protoc_gen_swagger.options.Schema\x12U\n\nextensions\x18\x05 \x03(\x0b\x32\x41.grpc.gateway.protoc_gen_swagger.options.Response.ExtensionsEntry\x1aI\n\x0f\x45xtensionsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12%\n\x05value\x18\x02 \x01(\x0b\x32\x16.google.protobuf.Value:\x02\x38\x01J\x04\x08\x03\x10\x04J\x04\x08\x04\x10\x05\"\xf9\x02\n\x04Info\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x18\n\x10terms_of_service\x18\x03 \x01(\t\x12\x41\n\x07\x63ontact\x18\x04 \x01(\x0b\x32\x30.grpc.gateway.protoc_gen_swagger.options.Contact\x12\x41\n\x07license\x18\x05 \x01(\x0b\x32\x30.grpc.gateway.protoc_gen_swagger.options.License\x12\x0f\n\x07version\x18\x06 \x01(\t\x12Q\n\nextensions\x18\x07 \x03(\x0b\x32=.grpc.gateway.protoc_gen_swagger.options.Info.ExtensionsEntry\x1aI\n\x0f\x45xtensionsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12%\n\x05value\x18\x02 \x01(\x0b\x32\x16.google.protobuf.Value:\x02\x38\x01\"3\n\x07\x43ontact\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0b\n\x03url\x18\x02 \x01(\t\x12\r\n\x05\x65mail\x18\x03 \x01(\t\"$\n\x07License\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0b\n\x03url\x18\x02 \x01(\t\"9\n\x15\x45xternalDocumentation\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x0b\n\x03url\x18\x02 \x01(\t\"\x80\x02\n\x06Schema\x12H\n\x0bjson_schema\x18\x01 \x01(\x0b\x32\x33.grpc.gateway.protoc_gen_swagger.options.JSONSchema\x12\x15\n\rdiscriminator\x18\x02 \x01(\t\x12\x11\n\tread_only\x18\x03 \x01(\x08\x12U\n\rexternal_docs\x18\x05 \x01(\x0b\x32>.grpc.gateway.protoc_gen_swagger.options.ExternalDocumentation\x12%\n\x07\x65xample\x18\x06 \x01(\x0b\x32\x14.google.protobuf.AnyJ\x04\x08\x04\x10\x05\"\xba\x05\n\nJSONSchema\x12\x0b\n\x03ref\x18\x03 \x01(\t\x12\r\n\x05title\x18\x05 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x06 \x01(\t\x12\x0f\n\x07\x64\x65\x66\x61ult\x18\x07 \x01(\t\x12\x11\n\tread_only\x18\x08 \x01(\x08\x12\x13\n\x0bmultiple_of\x18\n \x01(\x01\x12\x0f\n\x07maximum\x18\x0b \x01(\x01\x12\x19\n\x11\x65xclusive_maximum\x18\x0c \x01(\x08\x12\x0f\n\x07minimum\x18\r \x01(\x01\x12\x19\n\x11\x65xclusive_minimum\x18\x0e \x01(\x08\x12\x12\n\nmax_length\x18\x0f \x01(\x04\x12\x12\n\nmin_length\x18\x10 \x01(\x04\x12\x0f\n\x07pattern\x18\x11 \x01(\t\x12\x11\n\tmax_items\x18\x14 \x01(\x04\x12\x11\n\tmin_items\x18\x15 \x01(\x04\x12\x14\n\x0cunique_items\x18\x16 \x01(\x08\x12\x16\n\x0emax_properties\x18\x18 \x01(\x04\x12\x16\n\x0emin_properties\x18\x19 \x01(\x04\x12\x10\n\x08required\x18\x1a \x03(\t\x12\r\n\x05\x61rray\x18\" \x03(\t\x12W\n\x04type\x18# \x03(\x0e\x32I.grpc.gateway.protoc_gen_swagger.options.JSONSchema.JSONSchemaSimpleTypes\"w\n\x15JSONSchemaSimpleTypes\x12\x0b\n\x07UNKNOWN\x10\x00\x12\t\n\x05\x41RRAY\x10\x01\x12\x0b\n\x07\x42OOLEAN\x10\x02\x12\x0b\n\x07INTEGER\x10\x03\x12\x08\n\x04NULL\x10\x04\x12\n\n\x06NUMBER\x10\x05\x12\n\n\x06OBJECT\x10\x06\x12\n\n\x06STRING\x10\x07J\x04\x08\x01\x10\x02J\x04\x08\x02\x10\x03J\x04\x08\x04\x10\x05J\x04\x08\t\x10\nJ\x04\x08\x12\x10\x13J\x04\x08\x13\x10\x14J\x04\x08\x17\x10\x18J\x04\x08\x1b\x10\x1cJ\x04\x08\x1c\x10\x1dJ\x04\x08\x1d\x10\x1eJ\x04\x08\x1e\x10\"J\x04\x08$\x10*J\x04\x08*\x10+J\x04\x08+\x10.\"w\n\x03Tag\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12U\n\rexternal_docs\x18\x03 \x01(\x0b\x32>.grpc.gateway.protoc_gen_swagger.options.ExternalDocumentationJ\x04\x08\x01\x10\x02\"\xdd\x01\n\x13SecurityDefinitions\x12\\\n\x08security\x18\x01 \x03(\x0b\x32J.grpc.gateway.protoc_gen_swagger.options.SecurityDefinitions.SecurityEntry\x1ah\n\rSecurityEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x46\n\x05value\x18\x02 \x01(\x0b\x32\x37.grpc.gateway.protoc_gen_swagger.options.SecurityScheme:\x02\x38\x01\"\x96\x06\n\x0eSecurityScheme\x12J\n\x04type\x18\x01 \x01(\x0e\x32<.grpc.gateway.protoc_gen_swagger.options.SecurityScheme.Type\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x46\n\x02in\x18\x04 \x01(\x0e\x32:.grpc.gateway.protoc_gen_swagger.options.SecurityScheme.In\x12J\n\x04\x66low\x18\x05 \x01(\x0e\x32<.grpc.gateway.protoc_gen_swagger.options.SecurityScheme.Flow\x12\x19\n\x11\x61uthorization_url\x18\x06 \x01(\t\x12\x11\n\ttoken_url\x18\x07 \x01(\t\x12?\n\x06scopes\x18\x08 \x01(\x0b\x32/.grpc.gateway.protoc_gen_swagger.options.Scopes\x12[\n\nextensions\x18\t \x03(\x0b\x32G.grpc.gateway.protoc_gen_swagger.options.SecurityScheme.ExtensionsEntry\x1aI\n\x0f\x45xtensionsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12%\n\x05value\x18\x02 \x01(\x0b\x32\x16.google.protobuf.Value:\x02\x38\x01\"K\n\x04Type\x12\x10\n\x0cTYPE_INVALID\x10\x00\x12\x0e\n\nTYPE_BASIC\x10\x01\x12\x10\n\x0cTYPE_API_KEY\x10\x02\x12\x0f\n\x0bTYPE_OAUTH2\x10\x03\"1\n\x02In\x12\x0e\n\nIN_INVALID\x10\x00\x12\x0c\n\x08IN_QUERY\x10\x01\x12\r\n\tIN_HEADER\x10\x02\"j\n\x04\x46low\x12\x10\n\x0c\x46LOW_INVALID\x10\x00\x12\x11\n\rFLOW_IMPLICIT\x10\x01\x12\x11\n\rFLOW_PASSWORD\x10\x02\x12\x14\n\x10\x46LOW_APPLICATION\x10\x03\x12\x14\n\x10\x46LOW_ACCESS_CODE\x10\x04\"\xc9\x02\n\x13SecurityRequirement\x12s\n\x14security_requirement\x18\x01 \x03(\x0b\x32U.grpc.gateway.protoc_gen_swagger.options.SecurityRequirement.SecurityRequirementEntry\x1a)\n\x18SecurityRequirementValue\x12\r\n\x05scope\x18\x01 \x03(\t\x1a\x91\x01\n\x18SecurityRequirementEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x64\n\x05value\x18\x02 \x01(\x0b\x32U.grpc.gateway.protoc_gen_swagger.options.SecurityRequirement.SecurityRequirementValue:\x02\x38\x01\"\x81\x01\n\x06Scopes\x12I\n\x05scope\x18\x01 \x03(\x0b\x32:.grpc.gateway.protoc_gen_swagger.options.Scopes.ScopeEntry\x1a,\n\nScopeEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x43ZAgithub.com/grpc-ecosystem/grpc-gateway/protoc-gen-swagger/optionsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'protos.protoc_gen_swagger.options.openapiv2_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZAgithub.com/grpc-ecosystem/grpc-gateway/protoc-gen-swagger/options'
  _globals['_SWAGGER_RESPONSESENTRY']._loaded_options = None
  _globals['_SWAGGER_RESPONSESENTRY']._serialized_options = b'8\001'
  _globals['_SWAGGER_EXTENSIONSENTRY']._loaded_options = None
  _globals['_SWAGGER_EXTENSIONSENTRY']._serialized_options = b'8\001'
  _globals['_OPERATION_RESPONSESENTRY']._loaded_options = None
  _globals['_OPERATION_RESPONSESENTRY']._serialized_options = b'8\001'
  _globals['_OPERATION_EXTENSIONSENTRY']._loaded_options = None
  _globals['_OPERATION_EXTENSIONSENTRY']._serialized_options = b'8\001'
  _globals['_RESPONSE_EXTENSIONSENTRY']._loaded_options = None
  _globals['_RESPONSE_EXTENSIONSENTRY']._serialized_options = b'8\001'
  _globals['_INFO_EXTENSIONSENTRY']._loaded_options = None
  _globals['_INFO_EXTENSIONSENTRY']._serialized_options = b'8\001'
  _globals['_SECURITYDEFINITIONS_SECURITYENTRY']._loaded_options = None
  _globals['_SECURITYDEFINITIONS_SECURITYENTRY']._serialized_options = b'8\001'
  _globals['_SECURITYSCHEME_EXTENSIONSENTRY']._loaded_options = None
  _globals['_SECURITYSCHEME_EXTENSIONSENTRY']._serialized_options = b'8\001'
  _globals['_SECURITYREQUIREMENT_SECURITYREQUIREMENTENTRY']._loaded_options = None
  _globals['_SECURITYREQUIREMENT_SECURITYREQUIREMENTENTRY']._serialized_options = b'8\001'
  _globals['_SCOPES_SCOPEENTRY']._loaded_options = None
  _globals['_SCOPES_SCOPEENTRY']._serialized_options = b'8\001'
  _globals['_SWAGGER']._serialized_start=152
  _globals['_SWAGGER']._serialized_end=1080
  _globals['_SWAGGER_RESPONSESENTRY']._serialized_start=820
  _globals['_SWAGGER_RESPONSESENTRY']._serialized_end=919
  _globals['_SWAGGER_EXTENSIONSENTRY']._serialized_start=921
  _globals['_SWAGGER_EXTENSIONSENTRY']._serialized_end=994
  _globals['_SWAGGER_SWAGGERSCHEME']._serialized_start=996
  _globals['_SWAGGER_SWAGGERSCHEME']._serialized_end=1062
  _globals['_OPERATION']._serialized_start=1083
  _globals['_OPERATION']._serialized_end=1764
  _globals['_OPERATION_RESPONSESENTRY']._serialized_start=820
  _globals['_OPERATION_RESPONSESENTRY']._serialized_end=919
  _globals['_OPERATION_EXTENSIONSENTRY']._serialized_start=921
  _globals['_OPERATION_EXTENSIONSENTRY']._serialized_end=994
  _globals['_RESPONSE']._serialized_start=1767
  _globals['_RESPONSE']._serialized_end=2037
  _globals['_RESPONSE_EXTENSIONSENTRY']._serialized_start=921
  _globals['_RESPONSE_EXTENSIONSENTRY']._serialized_end=994
  _globals['_INFO']._serialized_start=2040
  _globals['_INFO']._serialized_end=2417
  _globals['_INFO_EXTENSIONSENTRY']._serialized_start=921
  _globals['_INFO_EXTENSIONSENTRY']._serialized_end=994
  _globals['_CONTACT']._serialized_start=2419
  _globals['_CONTACT']._serialized_end=2470
  _globals['_LICENSE']._serialized_start=2472
  _globals['_LICENSE']._serialized_end=2508
  _globals['_EXTERNALDOCUMENTATION']._serialized_start=2510
  _globals['_EXTERNALDOCUMENTATION']._serialized_end=2567
  _globals['_SCHEMA']._serialized_start=2570
  _globals['_SCHEMA']._serialized_end=2826
  _globals['_JSONSCHEMA']._serialized_start=2829
  _globals['_JSONSCHEMA']._serialized_end=3527
  _globals['_JSONSCHEMA_JSONSCHEMASIMPLETYPES']._serialized_start=3324
  _globals['_JSONSCHEMA_JSONSCHEMASIMPLETYPES']._serialized_end=3443
  _globals['_TAG']._serialized_start=3529
  _globals['_TAG']._serialized_end=3648
  _globals['_SECURITYDEFINITIONS']._serialized_start=3651
  _globals['_SECURITYDEFINITIONS']._serialized_end=3872
  _globals['_SECURITYDEFINITIONS_SECURITYENTRY']._serialized_start=3768
  _globals['_SECURITYDEFINITIONS_SECURITYENTRY']._serialized_end=3872
  _globals['_SECURITYSCHEME']._serialized_start=3875
  _globals['_SECURITYSCHEME']._serialized_end=4665
  _globals['_SECURITYSCHEME_EXTENSIONSENTRY']._serialized_start=921
  _globals['_SECURITYSCHEME_EXTENSIONSENTRY']._serialized_end=994
  _globals['_SECURITYSCHEME_TYPE']._serialized_start=4431
  _globals['_SECURITYSCHEME_TYPE']._serialized_end=4506
  _globals['_SECURITYSCHEME_IN']._serialized_start=4508
  _globals['_SECURITYSCHEME_IN']._serialized_end=4557
  _globals['_SECURITYSCHEME_FLOW']._serialized_start=4559
  _globals['_SECURITYSCHEME_FLOW']._serialized_end=4665
  _globals['_SECURITYREQUIREMENT']._serialized_start=4668
  _globals['_SECURITYREQUIREMENT']._serialized_end=4997
  _globals['_SECURITYREQUIREMENT_SECURITYREQUIREMENTVALUE']._serialized_start=4808
  _globals['_SECURITYREQUIREMENT_SECURITYREQUIREMENTVALUE']._serialized_end=4849
  _globals['_SECURITYREQUIREMENT_SECURITYREQUIREMENTENTRY']._serialized_start=4852
  _globals['_SECURITYREQUIREMENT_SECURITYREQUIREMENTENTRY']._serialized_end=4997
  _globals['_SCOPES']._serialized_start=5000
  _globals['_SCOPES']._serialized_end=5129
  _globals['_SCOPES_SCOPEENTRY']._serialized_start=5085
  _globals['_SCOPES_SCOPEENTRY']._serialized_end=5129
# @@protoc_insertion_point(module_scope)



import unittest
import time
from datetime import datetime, timedelta
from formant.sdk.cloud.v2.src.ingest_api import IngestAPI
from formant.sdk.cloud.v2.formant_ingest_api_client.models.ingestion_request import (
    IngestionRequest,
)
from formant.sdk.cloud.v2.src.query_api import QueryAPI
from formant.sdk.cloud.v2.formant_query_api_client.models.query import (
    Query,
    QueryTypesItem,
)

from formant.sdk.cloud.v2.formant_query_api_client.models.stream_data_points_item import (
    StreamDataPointsItem,
)
import dateutil.parser as parser
import os

DEFAULT_BASE_URL = "https://api.formant.io/v1"
DEFAULT_DEVICE_ID =  "404e2d2c-f95f-41d8-bce1-915e314a6898"

EMAIL = os.getenv("FORMANT_EMAIL")
PASSWORD = os.getenv("FORMANT_PASSWORD")
DEVICE_ID = os.getenv("DEVICE_ID", DEFAULT_DEVICE_ID)
BASE_URL = os.getenv("BASE_URL", DEFAULT_BASE_URL)

END_TIME_IS_NOW = os.getenv("END_TIME_IS_NOW", "true")

## PLEASE READ:
## There is no guarantee that the query will return any data, so the tests are designed to pass
## if the query returns 200 status code and the response does not contain any data, the test will print a warning

class TestQueries(unittest.TestCase):
    def __init__(self, *args, **kwargs):
        super(TestQueries, self).__init__(*args, **kwargs)
        if not EMAIL or not PASSWORD:
            raise Exception("Please provide FORMANT_EMAIL and FORMANT_PASSWORD in environment variables")

        self.client = QueryAPI(email=EMAIL, password=PASSWORD, base_url=BASE_URL)
        self.ingestClient = IngestAPI(email=EMAIL, password=PASSWORD, base_url=BASE_URL)
        self.device_id = DEVICE_ID
        self.tags = {}

        if END_TIME_IS_NOW == "true":
            self.end = datetime.utcnow()
            self.start = self.end - timedelta(hours=2)
        else:
            self.start = parser.isoparse("2022-11-11T02:00:00.000Z")
            self.end = parser.isoparse("2022-12-11T02:02:00.000Z")

    def check_query_result(self, result, attribute):
        self.assertEqual(result.status_code, 200, f"expected 200, got {result.status_code}")
        if result.parsed.items:
            stream_data_points_item = result.parsed.items[0].points[0]

            self.assertIsInstance(
                stream_data_points_item,
                StreamDataPointsItem,
                "not an instance of StreamDataPointsItem",
            )

            self.assertIsNotNone(getattr(stream_data_points_item, attribute), f"{attribute} value is None")
        else:
            # it's ok for the list to be empty
            print(f"warning! got empty items list for {attribute}")
            self.assertEqual(result.parsed.items, [], "got empty items list")


    def test_query_numeric(self):
        types = [QueryTypesItem.NUMERIC]
        query = Query(start=self.start, end=self.end, types=types, next_="true")
        result = self.client.queries.query(query=query)

        self.check_query_result(result, 'numeric')

    def test_query_text(self):
        types = [QueryTypesItem.TEXT]
        query = Query(start=self.start, end=self.end, types=types, next_="true")
        result = self.client.queries.query(query=query)

        self.check_query_result(result, 'text')

    def test_query_bitset(self):
        types = [QueryTypesItem.BITSET]
        query = Query(start=self.start, end=self.end, types=types, next_="true")
        result = self.client.queries.query(query=query)

        self.check_query_result(result, 'bitset')

    def test_query_localization(self):
        types = [QueryTypesItem.LOCALIZATION]
        query = Query(start=self.start, end=self.end, types=types, next_="true")
        result = self.client.queries.query(query=query)

        self.check_query_result(result, 'localization')

    def test_query_point_cloud(self):
        types = [QueryTypesItem.POINT_CLOUD]
        query = Query(start=self.start, end=self.end, types=types, next_="true")
        result = self.client.queries.query(query=query)

        self.check_query_result(result, 'point_cloud')

    def test_query_location(self):
        types = [QueryTypesItem.LOCATION]
        query = Query(start=self.start, end=self.end, types=types, next_="true")
        result = self.client.queries.query(query=query)

        self.check_query_result(result, 'location')

    def test_query_file(self):
        start = parser.isoparse("2022-11-11T02:00:00.000Z")
        end = parser.isoparse("2022-12-11T02:02:00.000Z")

        types = [QueryTypesItem.FILE]
        query = Query(start=start, end=end, types=types, next_="true")
        result = self.client.queries.query(query=query)

        self.check_query_result(result, 'file')

    def test_query_health(self):
        types = [QueryTypesItem.HEALTH]
        query = Query(start=self.start, end=self.end, types=types, next_="true")
        result = self.client.queries.query(query=query)

        self.check_query_result(result, 'health')

    def test_query_transform_tree(self):
        types = [QueryTypesItem.TRANSFORM_TREE]
        query = Query(start=self.start, end=self.end, types=types, next_="true")
        result = self.client.queries.query(query=query)

        self.check_query_result(result, 'transform_tree')

    def test_query_battery(self):
        types = [QueryTypesItem.BATTERY]
        query = Query(start=self.start, end=self.end, types=types, next_="true")
        result = self.client.queries.query(query=query)

        self.check_query_result(result, 'battery')

    def test_query_video(self):
        types = [QueryTypesItem.VIDEO]
        query = Query(start=self.start, end=self.end, types=types, next_="true")
        result = self.client.queries.query(query=query)

        self.check_query_result(result, 'video')

    def test_query_numeric_set(self):
        types = [QueryTypesItem.NUMERIC_SET]
        query = Query(start=self.start, end=self.end, types=types, next_="true")
        result = self.client.queries.query(query=query)

        self.check_query_result(result, 'numeric_set')

    def test_query_json(self):
        types = [QueryTypesItem.JSON]
        query = Query(start=self.start, end=self.end, types=types, next_="true")
        result = self.client.queries.query(query=query)

        self.check_query_result(result, 'json')

    def test_query_image(self):
        types = [QueryTypesItem.IMAGE]
        query = Query(start=self.start, end=self.end, types=types, next_="true")
        result = self.client.queries.query(query=query)

        self.check_query_result(result, 'image')


unittest.main()



from typing import Any, Dict, List, Type, TypeVar

import attr

T = TypeVar("T", bound="TeleopHighPingReconnectBehaviors")


@attr.s(auto_attribs=True)
class TeleopHighPingReconnectBehaviors:
    """
    Attributes:
        enabled (bool):
        max_ping_threshold (float):
        max_high_ping_warning_periods (float):
        recovery_threshhold (float):
        max_ping_disconnect_periods (float):
        max_ping_disconnect_threshold (float):
        should_retry (bool):
        loss_threshold (float):
        high_loss_periods (float):
    """

    enabled: bool
    max_ping_threshold: float
    max_high_ping_warning_periods: float
    recovery_threshhold: float
    max_ping_disconnect_periods: float
    max_ping_disconnect_threshold: float
    should_retry: bool
    loss_threshold: float
    high_loss_periods: float
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        enabled = self.enabled
        max_ping_threshold = self.max_ping_threshold
        max_high_ping_warning_periods = self.max_high_ping_warning_periods
        recovery_threshhold = self.recovery_threshhold
        max_ping_disconnect_periods = self.max_ping_disconnect_periods
        max_ping_disconnect_threshold = self.max_ping_disconnect_threshold
        should_retry = self.should_retry
        loss_threshold = self.loss_threshold
        high_loss_periods = self.high_loss_periods

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "enabled": enabled,
                "maxPingThreshold": max_ping_threshold,
                "maxHighPingWarningPeriods": max_high_ping_warning_periods,
                "recoveryThreshhold": recovery_threshhold,
                "maxPingDisconnectPeriods": max_ping_disconnect_periods,
                "maxPingDisconnectThreshold": max_ping_disconnect_threshold,
                "shouldRetry": should_retry,
                "lossThreshold": loss_threshold,
                "highLossPeriods": high_loss_periods,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        enabled = d.pop("enabled")

        max_ping_threshold = d.pop("maxPingThreshold")

        max_high_ping_warning_periods = d.pop("maxHighPingWarningPeriods")

        recovery_threshhold = d.pop("recoveryThreshhold")

        max_ping_disconnect_periods = d.pop("maxPingDisconnectPeriods")

        max_ping_disconnect_threshold = d.pop("maxPingDisconnectThreshold")

        should_retry = d.pop("shouldRetry")

        loss_threshold = d.pop("lossThreshold")

        high_loss_periods = d.pop("highLossPeriods")

        teleop_high_ping_reconnect_behaviors = cls(
            enabled=enabled,
            max_ping_threshold=max_ping_threshold,
            max_high_ping_warning_periods=max_high_ping_warning_periods,
            recovery_threshhold=recovery_threshhold,
            max_ping_disconnect_periods=max_ping_disconnect_periods,
            max_ping_disconnect_threshold=max_ping_disconnect_threshold,
            should_retry=should_retry,
            loss_threshold=loss_threshold,
            high_loss_periods=high_loss_periods,
        )

        teleop_high_ping_reconnect_behaviors.additional_properties = d
        return teleop_high_ping_reconnect_behaviors

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..models.device_stream_ros_topic_configuration_ros_version import DeviceStreamRosTopicConfigurationRosVersion
from ..models.device_stream_ros_topic_configuration_type import DeviceStreamRosTopicConfigurationType
from ..types import UNSET, Unset

T = TypeVar("T", bound="DeviceStreamRosTopicConfiguration")


@attr.s(auto_attribs=True)
class DeviceStreamRosTopicConfiguration:
    """
    Attributes:
        type (DeviceStreamRosTopicConfigurationType):
        topic (str):
        ros_version (DeviceStreamRosTopicConfigurationRosVersion):
        path (Union[Unset, str]):
    """

    type: DeviceStreamRosTopicConfigurationType
    topic: str
    ros_version: DeviceStreamRosTopicConfigurationRosVersion
    path: Union[Unset, str] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        type = self.type.value

        topic = self.topic
        ros_version = self.ros_version.value

        path = self.path

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "type": type,
                "topic": topic,
                "rosVersion": ros_version,
            }
        )
        if path is not UNSET:
            field_dict["path"] = path

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        type = DeviceStreamRosTopicConfigurationType(d.pop("type"))

        topic = d.pop("topic")

        ros_version = DeviceStreamRosTopicConfigurationRosVersion(d.pop("rosVersion"))

        path = d.pop("path", UNSET)

        device_stream_ros_topic_configuration = cls(
            type=type,
            topic=topic,
            ros_version=ros_version,
            path=path,
        )

        device_stream_ros_topic_configuration.additional_properties = d
        return device_stream_ros_topic_configuration

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

T = TypeVar("T", bound="Location")


@attr.s(auto_attribs=True)
class Location:
    """
    Attributes:
        latitude (float):
        longitude (float):
        altitude (Union[Unset, float]):
        orientation (Union[Unset, float]):
    """

    latitude: float
    longitude: float
    altitude: Union[Unset, float] = UNSET
    orientation: Union[Unset, float] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        latitude = self.latitude
        longitude = self.longitude
        altitude = self.altitude
        orientation = self.orientation

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "latitude": latitude,
                "longitude": longitude,
            }
        )
        if altitude is not UNSET:
            field_dict["altitude"] = altitude
        if orientation is not UNSET:
            field_dict["orientation"] = orientation

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        latitude = d.pop("latitude")

        longitude = d.pop("longitude")

        altitude = d.pop("altitude", UNSET)

        orientation = d.pop("orientation", UNSET)

        location = cls(
            latitude=latitude,
            longitude=longitude,
            altitude=altitude,
            orientation=orientation,
        )

        location.additional_properties = d
        return location

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



import datetime
from typing import Any, Dict, List, Type, TypeVar, Union, cast

import attr
from dateutil.parser import isoparse

from ..types import UNSET, Unset

T = TypeVar("T", bound="ChatMessage")


@attr.s(auto_attribs=True)
class ChatMessage:
    """
    Attributes:
        message (str):
        organization_id (Union[Unset, str]):
        exploration_id (Union[Unset, str]):
        sender (Union[Unset, str]):
        enabled (Union[Unset, bool]):
        thoughts (Union[Unset, List[Any]]):
        id (Union[Unset, str]):
        created_at (Union[Unset, datetime.datetime]):
        updated_at (Union[Unset, datetime.datetime]):
    """

    message: str
    organization_id: Union[Unset, str] = UNSET
    exploration_id: Union[Unset, str] = UNSET
    sender: Union[Unset, str] = UNSET
    enabled: Union[Unset, bool] = UNSET
    thoughts: Union[Unset, List[Any]] = UNSET
    id: Union[Unset, str] = UNSET
    created_at: Union[Unset, datetime.datetime] = UNSET
    updated_at: Union[Unset, datetime.datetime] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        message = self.message
        organization_id = self.organization_id
        exploration_id = self.exploration_id
        sender = self.sender
        enabled = self.enabled
        thoughts: Union[Unset, List[Any]] = UNSET
        if not isinstance(self.thoughts, Unset):
            thoughts = self.thoughts

        id = self.id
        created_at: Union[Unset, str] = UNSET
        if not isinstance(self.created_at, Unset):
            created_at = self.created_at.isoformat()

        updated_at: Union[Unset, str] = UNSET
        if not isinstance(self.updated_at, Unset):
            updated_at = self.updated_at.isoformat()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "message": message,
            }
        )
        if organization_id is not UNSET:
            field_dict["organizationId"] = organization_id
        if exploration_id is not UNSET:
            field_dict["explorationId"] = exploration_id
        if sender is not UNSET:
            field_dict["sender"] = sender
        if enabled is not UNSET:
            field_dict["enabled"] = enabled
        if thoughts is not UNSET:
            field_dict["thoughts"] = thoughts
        if id is not UNSET:
            field_dict["id"] = id
        if created_at is not UNSET:
            field_dict["createdAt"] = created_at
        if updated_at is not UNSET:
            field_dict["updatedAt"] = updated_at

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        message = d.pop("message")

        organization_id = d.pop("organizationId", UNSET)

        exploration_id = d.pop("explorationId", UNSET)

        sender = d.pop("sender", UNSET)

        enabled = d.pop("enabled", UNSET)

        thoughts = cast(List[Any], d.pop("thoughts", UNSET))

        id = d.pop("id", UNSET)

        _created_at = d.pop("createdAt", UNSET)
        created_at: Union[Unset, datetime.datetime]
        if isinstance(_created_at, Unset):
            created_at = UNSET
        else:
            created_at = isoparse(_created_at)

        _updated_at = d.pop("updatedAt", UNSET)
        updated_at: Union[Unset, datetime.datetime]
        if isinstance(_updated_at, Unset):
            updated_at = UNSET
        else:
            updated_at = isoparse(_updated_at)

        chat_message = cls(
            message=message,
            organization_id=organization_id,
            exploration_id=exploration_id,
            sender=sender,
            enabled=enabled,
            thoughts=thoughts,
            id=id,
            created_at=created_at,
            updated_at=updated_at,
        )

        chat_message.additional_properties = d
        return chat_message

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: protos/model/v1/navigation.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'protos/model/v1/navigation.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from formant.protos.model.v1 import math_pb2 as protos_dot_model_dot_v1_dot_math__pb2
from formant.protos.model.v1 import media_pb2 as protos_dot_model_dot_v1_dot_media__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n protos/model/v1/navigation.proto\x12\x08v1.model\x1a\x1aprotos/model/v1/math.proto\x1a\x1bprotos/model/v1/media.proto\"}\n\x08Location\x12\x10\n\x08latitude\x18\x01 \x01(\x01\x12\x11\n\tlongitude\x18\x02 \x01(\x01\x12\x15\n\x08\x61ltitude\x18\x03 \x01(\x01H\x00\x88\x01\x01\x12\x18\n\x0borientation\x18\x04 \x01(\x01H\x01\x88\x01\x01\x42\x0b\n\t_altitudeB\x0e\n\x0c_orientation\"\xcc\x01\n\x0cLocalization\x12$\n\x08odometry\x18\x01 \x01(\x0b\x32\x12.v1.model.Odometry\x12\x1a\n\x03map\x18\x02 \x01(\x0b\x32\r.v1.model.Map\x12*\n\x0cpoint_clouds\x18\x03 \x03(\x0b\x32\x14.v1.model.PointCloud\x12\x1c\n\x04path\x18\x04 \x01(\x0b\x32\x0e.v1.model.Path\x12\x1c\n\x04goal\x18\x05 \x01(\x0b\x32\x0e.v1.model.Goal\x12\x12\n\nrosVersion\x18\x06 \x01(\t\"z\n\x08Odometry\x12!\n\x04pose\x18\x01 \x01(\x0b\x32\x13.v1.model.Transform\x12\x1e\n\x05twist\x18\x02 \x01(\x0b\x32\x0f.v1.model.Twist\x12+\n\x0eworld_to_local\x18\x03 \x01(\x0b\x32\x13.v1.model.Transform\"\xf1\x01\n\x03Map\x12\x0c\n\x04uuid\x18\t \x01(\t\x12\x12\n\nresolution\x18\x01 \x01(\x01\x12\r\n\x05width\x18\x02 \x01(\r\x12\x0e\n\x06height\x18\x03 \x01(\r\x12#\n\x06origin\x18\x04 \x01(\x0b\x32\x13.v1.model.Transform\x12+\n\x0eworld_to_local\x18\x05 \x01(\x0b\x32\x13.v1.model.Transform\x12\x31\n\x0eoccupancy_grid\x18\x06 \x01(\x0b\x32\x17.v1.model.OccupancyGridH\x00\x12\r\n\x03url\x18\x07 \x01(\tH\x00\x12\r\n\x03raw\x18\x08 \x01(\x0cH\x00\x42\x06\n\x04\x64\x61ta\"\x1d\n\rOccupancyGrid\x12\x0c\n\x04\x64\x61ta\x18\x01 \x03(\x05\"W\n\x04Path\x12+\n\x0eworld_to_local\x18\x01 \x01(\x0b\x32\x13.v1.model.Transform\x12\"\n\x05poses\x18\x02 \x03(\x0b\x32\x13.v1.model.Transform\"{\n\nJointState\x12+\n\x0eworld_to_local\x18\x05 \x01(\x0b\x32\x13.v1.model.Transform\x12\x0c\n\x04name\x18\x01 \x03(\t\x12\x10\n\x08position\x18\x02 \x03(\x01\x12\x10\n\x08velocity\x18\x03 \x03(\x01\x12\x0e\n\x06\x65\x66\x66ort\x18\x04 \x03(\x01\"V\n\x04Goal\x12+\n\x0eworld_to_local\x18\x01 \x01(\x0b\x32\x13.v1.model.Transform\x12!\n\x04pose\x18\x02 \x01(\x0b\x32\x13.v1.model.Transform\"\x14\n\x06GoalID\x12\n\n\x02id\x18\x01 \x01(\t\"K\n\x12PoseWithCovariance\x12!\n\x04pose\x18\x01 \x01(\x0b\x32\x13.v1.model.Transform\x12\x12\n\ncovariance\x18\x02 \x03(\x01\"7\n\tColorRGBA\x12\t\n\x01r\x18\x01 \x01(\x02\x12\t\n\x01g\x18\x02 \x01(\x02\x12\t\n\x01\x62\x18\x03 \x01(\x02\x12\t\n\x01\x61\x18\x04 \x01(\x02\"\xa2\x03\n\x08Marker3D\x12+\n\x0eworld_to_local\x18\x01 \x01(\x0b\x32\x13.v1.model.Transform\x12\n\n\x02ns\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\x05\x12\x0c\n\x04type\x18\x04 \x01(\t\x12\x0e\n\x06\x61\x63tion\x18\x05 \x01(\t\x12!\n\x04pose\x18\x06 \x01(\x0b\x32\x13.v1.model.Transform\x12 \n\x05scale\x18\x07 \x01(\x0b\x32\x11.v1.model.Vector3\x12\"\n\x05\x63olor\x18\x08 \x01(\x0b\x32\x13.v1.model.ColorRGBA\x12\x10\n\x08lifetime\x18\t \x01(\x01\x12\x14\n\x0c\x66rame_locked\x18\n \x01(\x08\x12!\n\x06points\x18\x0b \x03(\x0b\x32\x11.v1.model.Vector3\x12#\n\x06\x63olors\x18\x0c \x03(\x0b\x32\x13.v1.model.ColorRGBA\x12\x0c\n\x04text\x18\r \x01(\t\x12\x15\n\rmesh_resource\x18\x0e \x01(\t\x12#\n\x1bmesh_use_embedded_materials\x18\x0f \x01(\x08\x12\x10\n\x08\x66rame_id\x18\x10 \x01(\t\"4\n\rMarker3DArray\x12#\n\x07markers\x18\x01 \x03(\x0b\x32\x12.v1.model.Marker3D\"$\n\x03Joy\x12\x0c\n\x04\x61xes\x18\x01 \x03(\x02\x12\x0f\n\x07\x62uttons\x18\x02 \x03(\x05\x42+Z)github.com/FormantIO/genproto/go/v1/modelb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'protos.model.v1.navigation_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z)github.com/FormantIO/genproto/go/v1/model'
  _globals['_LOCATION']._serialized_start=103
  _globals['_LOCATION']._serialized_end=228
  _globals['_LOCALIZATION']._serialized_start=231
  _globals['_LOCALIZATION']._serialized_end=435
  _globals['_ODOMETRY']._serialized_start=437
  _globals['_ODOMETRY']._serialized_end=559
  _globals['_MAP']._serialized_start=562
  _globals['_MAP']._serialized_end=803
  _globals['_OCCUPANCYGRID']._serialized_start=805
  _globals['_OCCUPANCYGRID']._serialized_end=834
  _globals['_PATH']._serialized_start=836
  _globals['_PATH']._serialized_end=923
  _globals['_JOINTSTATE']._serialized_start=925
  _globals['_JOINTSTATE']._serialized_end=1048
  _globals['_GOAL']._serialized_start=1050
  _globals['_GOAL']._serialized_end=1136
  _globals['_GOALID']._serialized_start=1138
  _globals['_GOALID']._serialized_end=1158
  _globals['_POSEWITHCOVARIANCE']._serialized_start=1160
  _globals['_POSEWITHCOVARIANCE']._serialized_end=1235
  _globals['_COLORRGBA']._serialized_start=1237
  _globals['_COLORRGBA']._serialized_end=1292
  _globals['_MARKER3D']._serialized_start=1295
  _globals['_MARKER3D']._serialized_end=1713
  _globals['_MARKER3DARRAY']._serialized_start=1715
  _globals['_MARKER3DARRAY']._serialized_end=1767
  _globals['_JOY']._serialized_start=1769
  _globals['_JOY']._serialized_end=1805
# @@protoc_insertion_point(module_scope)



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union, cast

import attr

from ..models.ingest_stream_data_type import IngestStreamDataType
from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.ingest_stream_data_tags import IngestStreamDataTags


T = TypeVar("T", bound="IngestStreamData")


@attr.s(auto_attribs=True)
class IngestStreamData:
    """
    Attributes:
        name (str):
        type (IngestStreamDataType):
        tags (IngestStreamDataTags):
        points (List[Any]):
        device_id (Union[Unset, str]):
        agent_id (Union[Unset, str]):
    """

    name: str
    type: IngestStreamDataType
    tags: "IngestStreamDataTags"
    points: List[Any]
    device_id: Union[Unset, str] = UNSET
    agent_id: Union[Unset, str] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        name = self.name
        type = self.type.value

        tags = self.tags.to_dict()

        points = self.points

        device_id = self.device_id
        agent_id = self.agent_id

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "name": name,
                "type": type,
                "tags": tags,
                "points": points,
            }
        )
        if device_id is not UNSET:
            field_dict["deviceId"] = device_id
        if agent_id is not UNSET:
            field_dict["agentId"] = agent_id

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.ingest_stream_data_tags import IngestStreamDataTags

        d = src_dict.copy()
        name = d.pop("name")

        type = IngestStreamDataType(d.pop("type"))

        tags = IngestStreamDataTags.from_dict(d.pop("tags"))

        points = cast(List[Any], d.pop("points"))

        device_id = d.pop("deviceId", UNSET)

        agent_id = d.pop("agentId", UNSET)

        ingest_stream_data = cls(
            name=name,
            type=type,
            tags=tags,
            points=points,
            device_id=device_id,
            agent_id=agent_id,
        )

        ingest_stream_data.additional_properties = d
        return ingest_stream_data

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.login_request_tags import LoginRequestTags


T = TypeVar("T", bound="LoginEmbedRequest")


@attr.s(auto_attribs=True)
class LoginEmbedRequest:
    """
    Attributes:
        email (str): Email address of your service account.
        password (str): Password of your service account.
        token_expiration_seconds (Union[Unset, int]): Number of seconds the token will be valid.
        tags (Union[Unset, LoginRequestTags]):
    """

    email: str
    password: str
    token_expiration_seconds: Union[Unset, int] = UNSET
    tags: Union[Unset, "LoginRequestTags"] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        email = self.email
        password = self.password
        token_expiration_seconds = self.token_expiration_seconds
        tags: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.tags, Unset):
            tags = self.tags.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "email": email,
                "password": password,
            }
        )
        if token_expiration_seconds is not UNSET:
            field_dict["tokenExpirationSeconds"] = token_expiration_seconds
        if tags is not UNSET:
            field_dict["tags"] = tags

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.login_request_tags import LoginRequestTags

        d = src_dict.copy()
        email = d.pop("email")

        password = d.pop("password")

        token_expiration_seconds = d.pop("tokenExpirationSeconds", UNSET)

        _tags = d.pop("tags", UNSET)
        tags: Union[Unset, LoginRequestTags]
        if isinstance(_tags, Unset):
            tags = UNSET
        else:
            tags = LoginRequestTags.from_dict(_tags)

        login_embed_request = cls(
            email=email,
            password=password,
            token_expiration_seconds=token_expiration_seconds,
            tags=tags,
        )

        login_embed_request.additional_properties = d
        return login_embed_request

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: protos/model/v1/views.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'protos/model/v1/views.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from formant.protos.model.v1 import datapoint_pb2 as protos_dot_model_dot_v1_dot_datapoint__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1bprotos/model/v1/views.proto\x12\x08v1.model\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1fprotos/model/v1/datapoint.proto\x1a\x1cgoogle/protobuf/struct.proto\"6\n\rViewsMetadata\x12%\n\x05views\x18\x01 \x03(\x0b\x32\x16.v1.model.ViewMetadata\"\xb5\x04\n\x0cViewMetadata\x12\n\n\x02id\x18\x01 \x01(\t\x12.\n\x04tags\x18\x02 \x03(\x0b\x32 .v1.model.ViewMetadata.TagsEntry\x12\x16\n\x0eorganizationId\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12\x0b\n\x03url\x18\x06 \x01(\t\x12\x1a\n\x12showOnSingleDevice\x18\x07 \x01(\x08\x12\x19\n\x11showOnMultiDevice\x18\x08 \x01(\x08\x12\x14\n\x0cshowOnTeleop\x18\t \x01(\x08\x12\x14\n\x0cshowTimeline\x18\x0b \x01(\x08\x12 \n\x06\x66ilter\x18\x0c \x01(\x0b\x32\x10.v1.model.Filter\x12\'\n\x06layout\x18\r \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x12\n\nlayoutType\x18\x0e \x01(\t\x12\x32\n\rconfiguration\x18\x0f \x03(\x0b\x32\x1b.v1.model.ViewConfiguration\x12\x14\n\x0csmartFleetId\x18\x10 \x01(\t\x12\r\n\x05index\x18\x11 \x01(\x03\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"S\n\nLayoutType\x12\r\n\tDASHBOARD\x10\x00\x12\x0b\n\x07OBSERVE\x10\x01\x12\x0e\n\nFULLSCREEN\x10\x02\x12\r\n\tANALYTICS\x10\x03\x12\n\n\x06TELEOP\x10\x04J\x04\x08\n\x10\x0b\"\x94\x02\n\x06\x46ilter\x12(\n\x04tags\x18\x01 \x03(\x0b\x32\x1a.v1.model.Filter.TagsEntry\x12\r\n\x05names\x18\x02 \x03(\t\x12\r\n\x05types\x18\x03 \x03(\t\x12\x11\n\tdeviceIds\x18\x04 \x03(\t\x12.\n\x07notTags\x18\x05 \x03(\x0b\x32\x1d.v1.model.Filter.NotTagsEntry\x12\x10\n\x08notNames\x18\x06 \x03(\t\x12\x10\n\x08\x61gentIds\x18\x07 \x03(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a.\n\x0cNotTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"e\n\x11ViewConfiguration\x12\x12\n\nstreamName\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t\x12.\n\rconfiguration\x18\x03 \x01(\x0b\x32\x17.google.protobuf.StructB+Z)github.com/FormantIO/genproto/go/v1/modelb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'protos.model.v1.views_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z)github.com/FormantIO/genproto/go/v1/model'
  _globals['_VIEWMETADATA_TAGSENTRY']._loaded_options = None
  _globals['_VIEWMETADATA_TAGSENTRY']._serialized_options = b'8\001'
  _globals['_FILTER_TAGSENTRY']._loaded_options = None
  _globals['_FILTER_TAGSENTRY']._serialized_options = b'8\001'
  _globals['_FILTER_NOTTAGSENTRY']._loaded_options = None
  _globals['_FILTER_NOTTAGSENTRY']._serialized_options = b'8\001'
  _globals['_VIEWSMETADATA']._serialized_start=137
  _globals['_VIEWSMETADATA']._serialized_end=191
  _globals['_VIEWMETADATA']._serialized_start=194
  _globals['_VIEWMETADATA']._serialized_end=759
  _globals['_VIEWMETADATA_TAGSENTRY']._serialized_start=625
  _globals['_VIEWMETADATA_TAGSENTRY']._serialized_end=668
  _globals['_VIEWMETADATA_LAYOUTTYPE']._serialized_start=670
  _globals['_VIEWMETADATA_LAYOUTTYPE']._serialized_end=753
  _globals['_FILTER']._serialized_start=762
  _globals['_FILTER']._serialized_end=1038
  _globals['_FILTER_TAGSENTRY']._serialized_start=625
  _globals['_FILTER_TAGSENTRY']._serialized_end=668
  _globals['_FILTER_NOTTAGSENTRY']._serialized_start=992
  _globals['_FILTER_NOTTAGSENTRY']._serialized_end=1038
  _globals['_VIEWCONFIGURATION']._serialized_start=1040
  _globals['_VIEWCONFIGURATION']._serialized_end=1141
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: protos/model/v1/intervention.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'protos/model/v1/intervention.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from formant.protos.model.v1 import media_pb2 as protos_dot_model_dot_v1_dot_media__pb2
from formant.protos.model.v1 import event_pb2 as protos_dot_model_dot_v1_dot_event__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"protos/model/v1/intervention.proto\x12\x08v1.model\x1a\x1bprotos/model/v1/media.proto\x1a\x1bprotos/model/v1/event.proto\"\x9c\x03\n\x13InterventionRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\ttimestamp\x18\x02 \x01(\x03\x12$\n\x08severity\x18\x03 \x01(\x0e\x32\x12.v1.model.Severity\x12\x37\n\x11selection_request\x18\x04 \x01(\x0b\x32\x1a.v1.model.SelectionRequestH\x00\x12\x35\n\x10labeling_request\x18\x05 \x01(\x0b\x32\x19.v1.model.LabelingRequestH\x00\x12\x31\n\x0eteleop_request\x18\x08 \x01(\x0b\x32\x17.v1.model.TeleopRequestH\x00\x12\x35\n\x04tags\x18\x06 \x03(\x0b\x32\'.v1.model.InterventionRequest.TagsEntry\x12\x31\n\tresponses\x18\x07 \x03(\x0b\x32\x1e.v1.model.InterventionResponse\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x06\n\x04\x64\x61ta\"\xfa\x01\n\x14InterventionResponse\x12\n\n\x02id\x18\x01 \x01(\t\x12\x12\n\nrequest_id\x18\x02 \x01(\t\x12\x11\n\ttimestamp\x18\x03 \x01(\x03\x12\x39\n\x12selection_response\x18\x04 \x01(\x0b\x32\x1b.v1.model.SelectionResponseH\x00\x12\x37\n\x11labeling_response\x18\x05 \x01(\x0b\x32\x1a.v1.model.LabelingResponseH\x00\x12\x33\n\x0fteleop_response\x18\x06 \x01(\x0b\x32\x18.v1.model.TeleopResponseH\x00\x42\x06\n\x04\x64\x61ta\",\n\x05Label\x12\r\n\x05value\x18\x01 \x01(\t\x12\x14\n\x0c\x64isplay_name\x18\x02 \x01(\t\"D\n\x0eLabeledPolygon\x12\"\n\x08vertices\x18\x01 \x03(\x0b\x32\x10.v1.model.Vertex\x12\x0e\n\x06labels\x18\x02 \x03(\t\"\x1e\n\x06Vertex\x12\t\n\x01x\x18\x01 \x01(\x01\x12\t\n\x01y\x18\x02 \x01(\x01\"\x9e\x01\n\x0fLabelingRequest\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0binstruction\x18\x02 \x01(\t\x12\x1e\n\x05image\x18\x03 \x01(\x0b\x32\x0f.v1.model.Image\x12\x1f\n\x06labels\x18\x04 \x03(\x0b\x32\x0f.v1.model.Label\x12&\n\x04hint\x18\x05 \x03(\x0b\x32\x18.v1.model.LabeledPolygon\";\n\x10LabelingResponse\x12\'\n\x05value\x18\x01 \x03(\x0b\x32\x18.v1.model.LabeledPolygon\"\x7f\n\x10SelectionRequest\x12\r\n\x05title\x18\x01 \x01(\t\x12 \n\x05image\x18\x02 \x01(\x0b\x32\x0f.v1.model.ImageH\x00\x12\x13\n\x0binstruction\x18\x03 \x01(\t\x12\x0f\n\x07options\x18\x04 \x03(\t\x12\x0c\n\x04hint\x18\x05 \x01(\rB\x06\n\x04\x64\x61ta\"\"\n\x11SelectionResponse\x12\r\n\x05value\x18\x01 \x01(\r\"$\n\rTeleopRequest\x12\x13\n\x0binstruction\x18\x01 \x01(\t\".\n\x0eTeleopResponse\x12\r\n\x05state\x18\x01 \x01(\t\x12\r\n\x05notes\x18\x02 \x01(\tB+Z)github.com/FormantIO/genproto/go/v1/modelb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'protos.model.v1.intervention_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z)github.com/FormantIO/genproto/go/v1/model'
  _globals['_INTERVENTIONREQUEST_TAGSENTRY']._loaded_options = None
  _globals['_INTERVENTIONREQUEST_TAGSENTRY']._serialized_options = b'8\001'
  _globals['_INTERVENTIONREQUEST']._serialized_start=107
  _globals['_INTERVENTIONREQUEST']._serialized_end=519
  _globals['_INTERVENTIONREQUEST_TAGSENTRY']._serialized_start=468
  _globals['_INTERVENTIONREQUEST_TAGSENTRY']._serialized_end=511
  _globals['_INTERVENTIONRESPONSE']._serialized_start=522
  _globals['_INTERVENTIONRESPONSE']._serialized_end=772
  _globals['_LABEL']._serialized_start=774
  _globals['_LABEL']._serialized_end=818
  _globals['_LABELEDPOLYGON']._serialized_start=820
  _globals['_LABELEDPOLYGON']._serialized_end=888
  _globals['_VERTEX']._serialized_start=890
  _globals['_VERTEX']._serialized_end=920
  _globals['_LABELINGREQUEST']._serialized_start=923
  _globals['_LABELINGREQUEST']._serialized_end=1081
  _globals['_LABELINGRESPONSE']._serialized_start=1083
  _globals['_LABELINGRESPONSE']._serialized_end=1142
  _globals['_SELECTIONREQUEST']._serialized_start=1144
  _globals['_SELECTIONREQUEST']._serialized_end=1271
  _globals['_SELECTIONRESPONSE']._serialized_start=1273
  _globals['_SELECTIONRESPONSE']._serialized_end=1307
  _globals['_TELEOPREQUEST']._serialized_start=1309
  _globals['_TELEOPREQUEST']._serialized_end=1345
  _globals['_TELEOPRESPONSE']._serialized_start=1347
  _globals['_TELEOPRESPONSE']._serialized_end=1393
# @@protoc_insertion_point(module_scope)



import datetime
from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

import attr
from dateutil.parser import isoparse

from ..models.command_stream_type import CommandStreamType
from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.command_parameter import CommandParameter
    from ..models.command_tags import CommandTags


T = TypeVar("T", bound="Command")


@attr.s(auto_attribs=True)
class Command:
    """
    Attributes:
        device_id (str): ID of the device on which this command should run.
        command (str): Function, script, or routine to execute.
        parameter (CommandParameter):
        organization_id (Union[Unset, str]): ID of the organization in which you want to create this new command
            instance.
        user_id (Union[Unset, None, str]): ID of the user who issued this command.
        command_template_id (Union[Unset, None, str]):
        event_trigger_id (Union[Unset, str]): Used by Formant agent only, ignore.
        delivered_at (Union[Unset, None, datetime.datetime]): Used by Formant agent only, ignore.
        canceled_at (Union[Unset, None, datetime.datetime]): Used by Formant agent only, ignore.
        responded_at (Union[Unset, None, datetime.datetime]): Used by Formant agent only, ignore.
        success (Union[Unset, None, bool]): Used by Formant agent only, ignore.
        stream_name (Union[Unset, None, str]): Used by Formant agent only, ignore.
        stream_type (Union[Unset, None, CommandStreamType]): Used by Formant agent only, ignore.
        tags (Union[Unset, None, CommandTags]): Tags associated with this command instance.
        id (Union[Unset, str]):
        created_at (Union[Unset, datetime.datetime]):
        updated_at (Union[Unset, datetime.datetime]):
    """

    device_id: str
    command: str
    parameter: "CommandParameter"
    organization_id: Union[Unset, str] = UNSET
    user_id: Union[Unset, None, str] = UNSET
    command_template_id: Union[Unset, None, str] = UNSET
    event_trigger_id: Union[Unset, str] = UNSET
    delivered_at: Union[Unset, None, datetime.datetime] = UNSET
    canceled_at: Union[Unset, None, datetime.datetime] = UNSET
    responded_at: Union[Unset, None, datetime.datetime] = UNSET
    success: Union[Unset, None, bool] = UNSET
    stream_name: Union[Unset, None, str] = UNSET
    stream_type: Union[Unset, None, CommandStreamType] = UNSET
    tags: Union[Unset, None, "CommandTags"] = UNSET
    id: Union[Unset, str] = UNSET
    created_at: Union[Unset, datetime.datetime] = UNSET
    updated_at: Union[Unset, datetime.datetime] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        device_id = self.device_id
        command = self.command
        parameter = self.parameter.to_dict()

        organization_id = self.organization_id
        user_id = self.user_id
        command_template_id = self.command_template_id
        event_trigger_id = self.event_trigger_id
        delivered_at: Union[Unset, None, str] = UNSET
        if not isinstance(self.delivered_at, Unset):
            delivered_at = self.delivered_at.isoformat() if self.delivered_at else None

        canceled_at: Union[Unset, None, str] = UNSET
        if not isinstance(self.canceled_at, Unset):
            canceled_at = self.canceled_at.isoformat() if self.canceled_at else None

        responded_at: Union[Unset, None, str] = UNSET
        if not isinstance(self.responded_at, Unset):
            responded_at = self.responded_at.isoformat() if self.responded_at else None

        success = self.success
        stream_name = self.stream_name
        stream_type: Union[Unset, None, str] = UNSET
        if not isinstance(self.stream_type, Unset):
            stream_type = self.stream_type.value if self.stream_type else None

        tags: Union[Unset, None, Dict[str, Any]] = UNSET
        if not isinstance(self.tags, Unset):
            tags = self.tags.to_dict() if self.tags else None

        id = self.id
        created_at: Union[Unset, str] = UNSET
        if not isinstance(self.created_at, Unset):
            created_at = self.created_at.isoformat()

        updated_at: Union[Unset, str] = UNSET
        if not isinstance(self.updated_at, Unset):
            updated_at = self.updated_at.isoformat()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "deviceId": device_id,
                "command": command,
                "parameter": parameter,
            }
        )
        if organization_id is not UNSET:
            field_dict["organizationId"] = organization_id
        if user_id is not UNSET:
            field_dict["userId"] = user_id
        if command_template_id is not UNSET:
            field_dict["commandTemplateId"] = command_template_id
        if event_trigger_id is not UNSET:
            field_dict["eventTriggerId"] = event_trigger_id
        if delivered_at is not UNSET:
            field_dict["deliveredAt"] = delivered_at
        if canceled_at is not UNSET:
            field_dict["canceledAt"] = canceled_at
        if responded_at is not UNSET:
            field_dict["respondedAt"] = responded_at
        if success is not UNSET:
            field_dict["success"] = success
        if stream_name is not UNSET:
            field_dict["streamName"] = stream_name
        if stream_type is not UNSET:
            field_dict["streamType"] = stream_type
        if tags is not UNSET:
            field_dict["tags"] = tags
        if id is not UNSET:
            field_dict["id"] = id
        if created_at is not UNSET:
            field_dict["createdAt"] = created_at
        if updated_at is not UNSET:
            field_dict["updatedAt"] = updated_at

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.command_parameter import CommandParameter
        from ..models.command_tags import CommandTags

        d = src_dict.copy()
        device_id = d.pop("deviceId")

        command = d.pop("command")

        parameter = CommandParameter.from_dict(d.pop("parameter"))

        organization_id = d.pop("organizationId", UNSET)

        user_id = d.pop("userId", UNSET)

        command_template_id = d.pop("commandTemplateId", UNSET)

        event_trigger_id = d.pop("eventTriggerId", UNSET)

        _delivered_at = d.pop("deliveredAt", UNSET)
        delivered_at: Union[Unset, None, datetime.datetime]
        if _delivered_at is None:
            delivered_at = None
        elif isinstance(_delivered_at, Unset):
            delivered_at = UNSET
        else:
            delivered_at = isoparse(_delivered_at)

        _canceled_at = d.pop("canceledAt", UNSET)
        canceled_at: Union[Unset, None, datetime.datetime]
        if _canceled_at is None:
            canceled_at = None
        elif isinstance(_canceled_at, Unset):
            canceled_at = UNSET
        else:
            canceled_at = isoparse(_canceled_at)

        _responded_at = d.pop("respondedAt", UNSET)
        responded_at: Union[Unset, None, datetime.datetime]
        if _responded_at is None:
            responded_at = None
        elif isinstance(_responded_at, Unset):
            responded_at = UNSET
        else:
            responded_at = isoparse(_responded_at)

        success = d.pop("success", UNSET)

        stream_name = d.pop("streamName", UNSET)

        _stream_type = d.pop("streamType", UNSET)
        stream_type: Union[Unset, None, CommandStreamType]
        if _stream_type is None:
            stream_type = None
        elif isinstance(_stream_type, Unset):
            stream_type = UNSET
        else:
            stream_type = CommandStreamType(_stream_type)

        _tags = d.pop("tags", UNSET)
        tags: Union[Unset, None, CommandTags]
        if _tags is None:
            tags = None
        elif isinstance(_tags, Unset):
            tags = UNSET
        else:
            tags = CommandTags.from_dict(_tags)

        id = d.pop("id", UNSET)

        _created_at = d.pop("createdAt", UNSET)
        created_at: Union[Unset, datetime.datetime]
        if isinstance(_created_at, Unset):
            created_at = UNSET
        else:
            created_at = isoparse(_created_at)

        _updated_at = d.pop("updatedAt", UNSET)
        updated_at: Union[Unset, datetime.datetime]
        if isinstance(_updated_at, Unset):
            updated_at = UNSET
        else:
            updated_at = isoparse(_updated_at)

        command = cls(
            device_id=device_id,
            command=command,
            parameter=parameter,
            organization_id=organization_id,
            user_id=user_id,
            command_template_id=command_template_id,
            event_trigger_id=event_trigger_id,
            delivered_at=delivered_at,
            canceled_at=canceled_at,
            responded_at=responded_at,
            success=success,
            stream_name=stream_name,
            stream_type=stream_type,
            tags=tags,
            id=id,
            created_at=created_at,
            updated_at=updated_at,
        )

        command.additional_properties = d
        return command

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



import sys
from typing import Any

python3 = True if sys.hexversion > 0x03000000 else False


# TODO: Do not require pointcloud2 as intermidate step
class PointCloud2:
    def __init__(
        self, height, width, is_dense, is_bigendian, fields, point_step, row_step
    ):
        self.height = height
        self.width = width
        self.is_dense = is_dense
        self.is_bigendian = is_bigendian
        self.fields = fields
        self.point_step = point_step
        self.row_step = row_step
        self.data = None  # type: Any


class PointField:

    _full_text = """# This message holds the description of one point entry in the
# PointCloud2 message format.
uint8 INT8    = 1
uint8 UINT8   = 2
uint8 INT16   = 3
uint8 UINT16  = 4
uint8 INT32   = 5
uint8 UINT32  = 6
uint8 FLOAT32 = 7
uint8 FLOAT64 = 8

string name      # Name of field
uint32 offset    # Offset from start of point struct
uint8  datatype  # Datatype enumeration, see above
uint32 count     # How many elements in the field
"""
    # Pseudo-constants
    INT8 = 1
    UINT8 = 2
    INT16 = 3
    UINT16 = 4
    INT32 = 5
    UINT32 = 6
    FLOAT32 = 7
    FLOAT64 = 8

    __slots__ = ["name", "offset", "datatype", "count"]
    _slot_types = ["string", "uint32", "uint8", "uint32"]

    def __init__(self, name, offset, datatype, count):
        self.name = name
        self.offset = offset
        self.datatype = datatype
        self.count = count



from enum import Enum


class DeviceTeleopRosStreamConfigurationTopicType(str, Enum):
    STD_MSGSFLOAT64 = "std_msgs/Float64"
    STD_MSGSBOOL = "std_msgs/Bool"
    GEOMETRY_MSGSTWIST = "geometry_msgs/Twist"
    SENSOR_MSGSCOMPRESSEDIMAGE = "sensor_msgs/CompressedImage"
    GEOMETRY_MSGSPOSESTAMPED = "geometry_msgs/PoseStamped"
    ACTIONLIB_MSGSGOALID = "actionlib_msgs/GoalID"
    FORMANTH264VIDEOFRAME = "formant/H264VideoFrame"
    AUDIO_COMMON_MSGSAUDIODATA = "audio_common_msgs/AudioData"
    SENSOR_MSGSJOINTSTATE = "sensor_msgs/JointState"
    GEOMETRY_MSGSPOSEWITHCOVARIANCESTAMPED = "geometry_msgs/PoseWithCovarianceStamped"
    SENSOR_MSGSLASERSCAN = "sensor_msgs/LaserScan"
    SENSOR_MSGSPOINTCLOUD2 = "sensor_msgs/PointCloud2"
    GEOMETRY_MSGSPOINTSTAMPED = "geometry_msgs/PointStamped"
    VISUALIZATION_MSGSMARKERARRAY = "visualization_msgs/MarkerArray"
    NAV_MSGSODOMETRY = "nav_msgs/Odometry"
    SENSOR_MSGSJOY = "sensor_msgs/Joy"

    def __str__(self) -> str:
        return str(self.value)



from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

T = TypeVar("T", bound="ForgotPasswordRequest")


@attr.s(auto_attribs=True)
class ForgotPasswordRequest:
    """
    Attributes:
        email (str): Email address to which to send a 'forgot password?' email.
        email_configuration_id (Union[Unset, str]): ID of the custom email template you want to use for the 'forgot
            password?' email.
    """

    email: str
    email_configuration_id: Union[Unset, str] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        email = self.email
        email_configuration_id = self.email_configuration_id

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "email": email,
            }
        )
        if email_configuration_id is not UNSET:
            field_dict["emailConfigurationId"] = email_configuration_id

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        email = d.pop("email")

        email_configuration_id = d.pop("emailConfigurationId", UNSET)

        forgot_password_request = cls(
            email=email,
            email_configuration_id=email_configuration_id,
        )

        forgot_password_request.additional_properties = d
        return forgot_password_request

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



import datetime
from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union, cast

import attr
from dateutil.parser import isoparse

from ..models.user_scope_types_item import UserScopeTypesItem
from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.scope_filter import ScopeFilter


T = TypeVar("T", bound="UserScope")


@attr.s(auto_attribs=True)
class UserScope:
    """
    Attributes:
        roles (Union[Unset, None, ScopeFilter]):
        users (Union[Unset, None, ScopeFilter]):
        teams (Union[Unset, None, ScopeFilter]):
        devices (Union[Unset, None, ScopeFilter]):
        fleets (Union[Unset, None, ScopeFilter]):
        events (Union[Unset, None, ScopeFilter]):
        views (Union[Unset, None, ScopeFilter]):
        key_value (Union[Unset, None, ScopeFilter]):
        tags (Union[Unset, Any]):
        device_ids (Union[Unset, List[str]]):
        names (Union[Unset, List[str]]):
        types (Union[Unset, List[UserScopeTypesItem]]):
        not_tags (Union[Unset, Any]):
        not_names (Union[Unset, List[str]]):
        agent_ids (Union[Unset, List[str]]):
        start (Union[Unset, datetime.datetime]):
        end (Union[Unset, datetime.datetime]):
    """

    roles: Union[Unset, None, "ScopeFilter"] = UNSET
    users: Union[Unset, None, "ScopeFilter"] = UNSET
    teams: Union[Unset, None, "ScopeFilter"] = UNSET
    devices: Union[Unset, None, "ScopeFilter"] = UNSET
    fleets: Union[Unset, None, "ScopeFilter"] = UNSET
    events: Union[Unset, None, "ScopeFilter"] = UNSET
    views: Union[Unset, None, "ScopeFilter"] = UNSET
    key_value: Union[Unset, None, "ScopeFilter"] = UNSET
    tags: Union[Unset, Any] = UNSET
    device_ids: Union[Unset, List[str]] = UNSET
    names: Union[Unset, List[str]] = UNSET
    types: Union[Unset, List[UserScopeTypesItem]] = UNSET
    not_tags: Union[Unset, Any] = UNSET
    not_names: Union[Unset, List[str]] = UNSET
    agent_ids: Union[Unset, List[str]] = UNSET
    start: Union[Unset, datetime.datetime] = UNSET
    end: Union[Unset, datetime.datetime] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        roles: Union[Unset, None, Dict[str, Any]] = UNSET
        if not isinstance(self.roles, Unset):
            roles = self.roles.to_dict() if self.roles else None

        users: Union[Unset, None, Dict[str, Any]] = UNSET
        if not isinstance(self.users, Unset):
            users = self.users.to_dict() if self.users else None

        teams: Union[Unset, None, Dict[str, Any]] = UNSET
        if not isinstance(self.teams, Unset):
            teams = self.teams.to_dict() if self.teams else None

        devices: Union[Unset, None, Dict[str, Any]] = UNSET
        if not isinstance(self.devices, Unset):
            devices = self.devices.to_dict() if self.devices else None

        fleets: Union[Unset, None, Dict[str, Any]] = UNSET
        if not isinstance(self.fleets, Unset):
            fleets = self.fleets.to_dict() if self.fleets else None

        events: Union[Unset, None, Dict[str, Any]] = UNSET
        if not isinstance(self.events, Unset):
            events = self.events.to_dict() if self.events else None

        views: Union[Unset, None, Dict[str, Any]] = UNSET
        if not isinstance(self.views, Unset):
            views = self.views.to_dict() if self.views else None

        key_value: Union[Unset, None, Dict[str, Any]] = UNSET
        if not isinstance(self.key_value, Unset):
            key_value = self.key_value.to_dict() if self.key_value else None

        tags = self.tags
        device_ids: Union[Unset, List[str]] = UNSET
        if not isinstance(self.device_ids, Unset):
            device_ids = self.device_ids

        names: Union[Unset, List[str]] = UNSET
        if not isinstance(self.names, Unset):
            names = self.names

        types: Union[Unset, List[str]] = UNSET
        if not isinstance(self.types, Unset):
            types = []
            for types_item_data in self.types:
                types_item = types_item_data.value

                types.append(types_item)

        not_tags = self.not_tags
        not_names: Union[Unset, List[str]] = UNSET
        if not isinstance(self.not_names, Unset):
            not_names = self.not_names

        agent_ids: Union[Unset, List[str]] = UNSET
        if not isinstance(self.agent_ids, Unset):
            agent_ids = self.agent_ids

        start: Union[Unset, str] = UNSET
        if not isinstance(self.start, Unset):
            start = self.start.isoformat()

        end: Union[Unset, str] = UNSET
        if not isinstance(self.end, Unset):
            end = self.end.isoformat()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if roles is not UNSET:
            field_dict["roles"] = roles
        if users is not UNSET:
            field_dict["users"] = users
        if teams is not UNSET:
            field_dict["teams"] = teams
        if devices is not UNSET:
            field_dict["devices"] = devices
        if fleets is not UNSET:
            field_dict["fleets"] = fleets
        if events is not UNSET:
            field_dict["events"] = events
        if views is not UNSET:
            field_dict["views"] = views
        if key_value is not UNSET:
            field_dict["keyValue"] = key_value
        if tags is not UNSET:
            field_dict["tags"] = tags
        if device_ids is not UNSET:
            field_dict["deviceIds"] = device_ids
        if names is not UNSET:
            field_dict["names"] = names
        if types is not UNSET:
            field_dict["types"] = types
        if not_tags is not UNSET:
            field_dict["notTags"] = not_tags
        if not_names is not UNSET:
            field_dict["notNames"] = not_names
        if agent_ids is not UNSET:
            field_dict["agentIds"] = agent_ids
        if start is not UNSET:
            field_dict["start"] = start
        if end is not UNSET:
            field_dict["end"] = end

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.scope_filter import ScopeFilter

        d = src_dict.copy()
        _roles = d.pop("roles", UNSET)
        roles: Union[Unset, None, ScopeFilter]
        if _roles is None:
            roles = None
        elif isinstance(_roles, Unset):
            roles = UNSET
        else:
            roles = ScopeFilter.from_dict(_roles)

        _users = d.pop("users", UNSET)
        users: Union[Unset, None, ScopeFilter]
        if _users is None:
            users = None
        elif isinstance(_users, Unset):
            users = UNSET
        else:
            users = ScopeFilter.from_dict(_users)

        _teams = d.pop("teams", UNSET)
        teams: Union[Unset, None, ScopeFilter]
        if _teams is None:
            teams = None
        elif isinstance(_teams, Unset):
            teams = UNSET
        else:
            teams = ScopeFilter.from_dict(_teams)

        _devices = d.pop("devices", UNSET)
        devices: Union[Unset, None, ScopeFilter]
        if _devices is None:
            devices = None
        elif isinstance(_devices, Unset):
            devices = UNSET
        else:
            devices = ScopeFilter.from_dict(_devices)

        _fleets = d.pop("fleets", UNSET)
        fleets: Union[Unset, None, ScopeFilter]
        if _fleets is None:
            fleets = None
        elif isinstance(_fleets, Unset):
            fleets = UNSET
        else:
            fleets = ScopeFilter.from_dict(_fleets)

        _events = d.pop("events", UNSET)
        events: Union[Unset, None, ScopeFilter]
        if _events is None:
            events = None
        elif isinstance(_events, Unset):
            events = UNSET
        else:
            events = ScopeFilter.from_dict(_events)

        _views = d.pop("views", UNSET)
        views: Union[Unset, None, ScopeFilter]
        if _views is None:
            views = None
        elif isinstance(_views, Unset):
            views = UNSET
        else:
            views = ScopeFilter.from_dict(_views)

        _key_value = d.pop("keyValue", UNSET)
        key_value: Union[Unset, None, ScopeFilter]
        if _key_value is None:
            key_value = None
        elif isinstance(_key_value, Unset):
            key_value = UNSET
        else:
            key_value = ScopeFilter.from_dict(_key_value)

        tags = d.pop("tags", UNSET)

        device_ids = cast(List[str], d.pop("deviceIds", UNSET))

        names = cast(List[str], d.pop("names", UNSET))

        types = []
        _types = d.pop("types", UNSET)
        for types_item_data in _types or []:
            types_item = UserScopeTypesItem(types_item_data)

            types.append(types_item)

        not_tags = d.pop("notTags", UNSET)

        not_names = cast(List[str], d.pop("notNames", UNSET))

        agent_ids = cast(List[str], d.pop("agentIds", UNSET))

        _start = d.pop("start", UNSET)
        start: Union[Unset, datetime.datetime]
        if isinstance(_start, Unset):
            start = UNSET
        else:
            start = isoparse(_start)

        _end = d.pop("end", UNSET)
        end: Union[Unset, datetime.datetime]
        if isinstance(_end, Unset):
            end = UNSET
        else:
            end = isoparse(_end)

        user_scope = cls(
            roles=roles,
            users=users,
            teams=teams,
            devices=devices,
            fleets=fleets,
            events=events,
            views=views,
            key_value=key_value,
            tags=tags,
            device_ids=device_ids,
            names=names,
            types=types,
            not_tags=not_tags,
            not_names=not_names,
            agent_ids=agent_ids,
            start=start,
            end=end,
        )

        user_scope.additional_properties = d
        return user_scope

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



import unittest
from formant.sdk.cloud.v2.src.admin_api import AdminAPI
from formant.sdk.cloud.v2.formant_admin_api_client.models import Annotation
from datetime import datetime
import os

EMAIL = os.getenv("FORMANT_EMAIL")
PASSWORD = os.getenv("FORMANT_PASSWORD")
BASE_URL = "https://api.formant.io/v1"


class TestAnnotations(unittest.TestCase):
    def __init__(self, *args, **kwargs):
        super(TestAnnotations, self).__init__(*args, **kwargs)
        self.client = AdminAPI(email=EMAIL, password=PASSWORD, base_url=BASE_URL)

    def test_get_annotation_list(self):
        result = self.client.annotations.list_templates()
        self.assertEqual(result.status_code, 200)

    def test_get_annotation_template(self):
        annotation_template_id = "d12707ed-9a78-4293-b11a-ad0ad75ad849"
        result = self.client.annotations.get_template(annotation_template_id)
        self.assertEqual(result.status_code, 200)

    def test_post_annotation(self):
        user_id = "408a7c6b-3b16-4667-a554-0fecc9d069dc"
        time = datetime.now()
        message = "Hello"
        annotation = Annotation(user_id=user_id, time=time, message=message)
        result = self.client.annotations.post(annotation)
        self.assertEqual(result.status_code, 201)


unittest.main()



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: protos/model/v1/ros.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'protos/model/v1/ros.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from formant.protos.model.v1 import math_pb2 as protos_dot_model_dot_v1_dot_math__pb2
from formant.protos.model.v1 import navigation_pb2 as protos_dot_model_dot_v1_dot_navigation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19protos/model/v1/ros.proto\x12\x08v1.model\x1a\x1aprotos/model/v1/math.proto\x1a protos/model/v1/navigation.proto\"P\n\x08ROSTopic\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04path\x18\x02 \x01(\t\x12\x14\n\x0c\x65ncode_video\x18\x03 \x01(\x08\x12\x12\n\nrosVersion\x18\x04 \x01(\t\"\xae\x01\n\x0fROSLocalization\x12\x11\n\tmap_topic\x18\x01 \x01(\t\x12\x12\n\nodom_topic\x18\x02 \x01(\t\x12\x1a\n\x12point_cloud_topics\x18\x03 \x03(\t\x12\x12\n\npath_topic\x18\x04 \x01(\t\x12\x12\n\ngoal_topic\x18\x05 \x01(\t\x12\x1c\n\x14\x62\x61se_reference_frame\x18\x06 \x01(\t\x12\x12\n\nrosVersion\x18\x07 \x01(\t\"0\n\x10ROSTransformTree\x12\x1c\n\x14\x62\x61se_reference_frame\x18\x01 \x01(\t\"\x9d\x03\n\x13ROSMessageToPublish\x12\x0e\n\x06stream\x18\x01 \x01(\t\x12\x10\n\x08\x66rame_id\x18\x07 \x01(\t\x12\x11\n\ttimestamp\x18\x08 \x01(\x04\x12 \n\x05twist\x18\x02 \x01(\x0b\x32\x0f.v1.model.TwistH\x00\x12\x0e\n\x04\x62ool\x18\x03 \x01(\x08H\x00\x12\x1a\n\x10\x63ompressed_image\x18\x04 \x01(\x0cH\x00\x12\x0e\n\x04text\x18\x05 \x01(\tH\x00\x12#\n\x04pose\x18\x06 \x01(\x0b\x32\x13.v1.model.TransformH\x00\x12\"\n\x06goalID\x18\t \x01(\x0b\x32\x10.v1.model.GoalIDH\x00\x12$\n\x07numeric\x18\n \x01(\x0b\x32\x11.v1.model.NumericH\x00\x12<\n\x14pose_with_covariance\x18\x0b \x01(\x0b\x32\x1c.v1.model.PoseWithCovarianceH\x00\x12 \n\x05point\x18\x0c \x01(\x0b\x32\x0f.v1.model.PointH\x00\x12\x1c\n\x03joy\x18\r \x01(\x0b\x32\r.v1.model.JoyH\x00\x42\x06\n\x04\x64\x61ta*\xd7\x03\n\x0cROSTopicType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x11\n\rSTD_MSGS_BOOL\x10\x01\x12 \n\x1cSENSOR_MSGS_COMPRESSED_IMAGE\x10\x02\x12\x13\n\x0fSTD_MSGS_STRING\x10\x03\x12\x16\n\x12GEOMETRY_MSGS_POSE\x10\x04\x12\x19\n\x15\x41\x43TIONLIB_MSGS_GOALID\x10\x05\x12\x17\n\x13GEOMETRY_MSGS_TWIST\x10\x06\x12\x14\n\x10H264_VIDEO_FRAME\x10\x07\x12\x0f\n\x0b\x41UDIO_CHUNK\x10\x08\x12\x14\n\x10STD_MSGS_FLOAT64\x10\t\x12\x1b\n\x17SENSOR_MSGS_JOINT_STATE\x10\n\x12&\n\"GEOMETRY_MSGS_POSE_WITH_COVARIANCE\x10\x0b\x12\x1c\n\x18SENSOR_MSGS_POINT_CLOUD2\x10\x0c\x12\x1a\n\x16SENSOR_MSGS_LASER_SCAN\x10\r\x12\x17\n\x13GEOMETRY_MSGS_POINT\x10\x0e\x12#\n\x1fVISUALIZATION_MSGS_MARKER_ARRAY\x10\x0f\x12\x15\n\x11NAV_MSGS_ODOMETRY\x10\x10\x12\x13\n\x0fSENSOR_MSGS_JOY\x10\x11\x42+Z)github.com/FormantIO/genproto/go/v1/modelb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'protos.model.v1.ros_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z)github.com/FormantIO/genproto/go/v1/model'
  _globals['_ROSTOPICTYPE']._serialized_start=827
  _globals['_ROSTOPICTYPE']._serialized_end=1298
  _globals['_ROSTOPIC']._serialized_start=101
  _globals['_ROSTOPIC']._serialized_end=181
  _globals['_ROSLOCALIZATION']._serialized_start=184
  _globals['_ROSLOCALIZATION']._serialized_end=358
  _globals['_ROSTRANSFORMTREE']._serialized_start=360
  _globals['_ROSTRANSFORMTREE']._serialized_end=408
  _globals['_ROSMESSAGETOPUBLISH']._serialized_start=411
  _globals['_ROSMESSAGETOPUBLISH']._serialized_end=824
# @@protoc_insertion_point(module_scope)
